@@ -32,60 +32,6 @@
 #include "gtr-tab.h"
 #include "gtr-window.h"
 
-void
-gtr_actions_edit_undo (GtrWindow * window)
-{
-  GtrView *active_view;
-  GtkSourceBuffer *active_document;
-  GtrTab *current;
-  GList *msg;
-  GtrPo *po;
-
-  current = gtr_window_get_active_tab (window);
-  po = gtr_tab_get_po (current);
-  msg = gtr_po_get_current_message (po);
-  active_view = gtr_window_get_active_view (window);
-
-  g_return_if_fail (active_view);
-
-  active_document =
-    GTK_SOURCE_BUFFER (gtk_text_view_get_buffer
-                       (GTK_TEXT_VIEW (active_view)));
-
-  if (gtk_text_buffer_get_can_undo (GTK_TEXT_BUFFER(active_document)))
-    gtk_text_buffer_undo (GTK_TEXT_BUFFER(active_document));
-
-  gtk_widget_grab_focus (GTK_WIDGET (active_view));
-  g_signal_emit_by_name (current, "message_changed", msg->data);
-}
-
-void
-gtr_actions_edit_redo (GtrWindow * window)
-{
-  GtrView *active_view;
-  GtkSourceBuffer *active_document;
-  GtrTab *current;
-  GList *msg;
-  GtrPo *po;
-
-  current = gtr_window_get_active_tab (window);
-  po = gtr_tab_get_po (current);
-  msg = gtr_po_get_current_message (po);
-
-  active_view = gtr_window_get_active_view (window);
-  g_return_if_fail (active_view);
-
-  active_document =
-    GTK_SOURCE_BUFFER (gtk_text_view_get_buffer
-                       (GTK_TEXT_VIEW (active_view)));
-
-  if (gtk_text_buffer_get_can_redo (GTK_TEXT_BUFFER(active_document)))
-    gtk_text_buffer_redo (GTK_TEXT_BUFFER(active_document));
-
-  gtk_widget_grab_focus (GTK_WIDGET (active_view));
-  g_signal_emit_by_name (current, "message_changed", msg->data);
-}
-
 void
 gtr_actions_edit_cut (GtrWindow * window)
 {
@@ -139,6 +85,19 @@ gtr_message_copy_to_translation (GtrWindow * window)
   gtr_tab_copy_to_translation (current);
 }
 
+/*
+ * Copy the original message to the clipboard.
+ */
+void
+gtr_message_copy_original (GtrWindow * window)
+{
+  GtrTab *current;
+
+  current = gtr_window_get_active_tab (window);
+
+  gtr_tab_copy_original (current);
+}
+
 /*
  * Toggle the sticky status
  */
@@ -161,7 +120,7 @@ gtr_message_status_toggle_fuzzy (GtrWindow * window)
   /*
    * Emit that message was changed.
    */
-  g_signal_emit_by_name (current, "message_changed", msg->data);
+  g_signal_emit_by_name (current, "message-changed", msg->data);
 }
 
 void
