@@ -43,17 +43,25 @@
 #include "gtr-window.h"
 #include "gtr-upload-dialog.h"
 
-#define GTR_TAB_SAVE_AS    "gtr-tab-save-as"
-#define GTR_IS_CLOSING_ALL "gtr-is-closing-all"
+#define GTR_TAB_SAVE_AS "gtr-tab-save-as"
 
 static void load_file_list (GtrWindow * window, const GSList * uris);
 static GList * get_modified_documents (GtrWindow * window);
 
 typedef struct {
-  SoupMessage *msg;
-  GtkWidget   *dialog;
+  SoupMessage     *msg;
+  GtrUploadDialog *dialog;
 } UserData;
 
+static void
+user_data_free (UserData *ud)
+{
+  g_object_unref (ud->msg);
+  adw_dialog_close (ADW_DIALOG (ud->dialog));
+
+  g_free (ud);
+}
+
 /*
  * The main file opening function. Checks that the file isn't already open,
  * and if not, opens it in a new tab.
@@ -163,20 +171,20 @@ gtr_po_parse_files_from_dialog (GObject *source, GAsyncResult *res, void *user_d
 }
 
 static void
-handle_save_current_dialog_response (AdwMessageDialog *dialog,
+handle_save_current_dialog_response (AdwAlertDialog *dialog,
                                      char *response,
                                      void (*callback)(GtrWindow *))
 {
   GtrWindow *window = gtr_application_get_active_window (GTR_APP);
 
   if (g_strcmp0 ("save", response) == 0)
-    gtr_save_current_file_dialog (NULL, window);
+    gtr_window_save_current_tab (window);
 
   // callback for "save", "close", and "no"
   if (g_strcmp0 ("cancel", response) != 0)
     callback (window);
 
-  gtk_window_destroy (GTK_WINDOW (dialog));
+  adw_dialog_force_close (ADW_DIALOG (dialog));
 }
 
 void
@@ -185,7 +193,7 @@ gtr_want_to_save_current_dialog (GtrWindow * window, void (*callback)(GtrWindow
   GtrTab *tab;
   GtrPo *po;
 
-  GtkWidget *dialog;
+  AdwDialog *dialog;
   g_autoptr (GFile) location = NULL;
   g_autofree gchar *basename = NULL;
 
@@ -194,27 +202,26 @@ gtr_want_to_save_current_dialog (GtrWindow * window, void (*callback)(GtrWindow
   location = gtr_po_get_location (po);
   basename = g_file_get_basename (location);
 
-  dialog = adw_message_dialog_new (GTK_WINDOW (window), _("Unsaved Changes"), NULL);
+  dialog = adw_alert_dialog_new (_("Unsaved Changes"), NULL);
+  adw_alert_dialog_set_body_use_markup (ADW_ALERT_DIALOG (dialog), TRUE);
 
-  adw_message_dialog_set_body_use_markup (ADW_MESSAGE_DIALOG (dialog), TRUE);
+  adw_alert_dialog_format_body (ADW_ALERT_DIALOG (dialog),
+                                _("Do you want to write all the changes done to %s?"),
+                                basename);
 
-  adw_message_dialog_format_body (ADW_MESSAGE_DIALOG (dialog),
-                                  _("Do you want to write all the changes done to %s?"),
-                                  basename);
-
-  adw_message_dialog_add_responses (ADW_MESSAGE_DIALOG (dialog),
-                                    "cancel", _("Cancel"),
-                                    "no", _("Continue Without Saving"),
-                                    "save", _("Save and Open"),
-                                    NULL);
-  adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (dialog),
+  adw_alert_dialog_add_responses (ADW_ALERT_DIALOG (dialog),
+                                  "cancel", _("Cancel"),
+                                  "no", _("Continue Without Saving"),
+                                  "save", _("Save and Open"),
+                                  NULL);
+  adw_alert_dialog_set_response_appearance (ADW_ALERT_DIALOG (dialog),
     "no", ADW_RESPONSE_DESTRUCTIVE);
-  adw_message_dialog_set_response_appearance (ADW_MESSAGE_DIALOG (dialog),
+  adw_alert_dialog_set_response_appearance (ADW_ALERT_DIALOG (dialog),
     "save", ADW_RESPONSE_SUGGESTED);
-  adw_message_dialog_set_default_response (ADW_MESSAGE_DIALOG (dialog), "save");
+  adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "save");
 
   g_signal_connect (dialog, "response", G_CALLBACK (handle_save_current_dialog_response), callback);
-  gtk_window_present (GTK_WINDOW (dialog));
+  adw_dialog_present (dialog, GTK_WIDGET (window));
 }
 
 /*
@@ -247,7 +254,7 @@ gtr_open_file_dialog (GtrWindow *window)
 static void
 save_dialog_response_cb (GObject *source, GAsyncResult *res, void *user_data)
 {
-  GError *error = NULL;
+  g_autoptr (GError) error = NULL;
   GtrPo *po;
   GtrTab *tab;
   GtkFileDialog *dialog = GTK_FILE_DIALOG (source);
@@ -274,10 +281,10 @@ save_dialog_response_cb (GObject *source, GAsyncResult *res, void *user_data)
 
       if (error)
         {
-          GtkAlertDialog *dialog = gtk_alert_dialog_new ("%s", error->message);
-          gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (window));
-          g_object_unref (dialog);
-          g_clear_error (&error);
+          AdwDialog *dialog = adw_alert_dialog_new (NULL, error->message);
+          adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+          adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
+          adw_dialog_present (ADW_DIALOG (dialog), GTK_WIDGET (window));
           return;
         }
 
@@ -297,15 +304,15 @@ _upload_file_callback (GObject      *object,
 {
   UserData *ud = user_data;
   g_autoptr(GInputStream) stream = NULL;
-  GtkAlertDialog *dialog;
+  AdwDialog *dialog = NULL;
   GtrTab *active_tab;
 
-  GtkWidget *upload_dialog = ud->dialog;
-  GtkWidget *window = gtr_upload_dialog_get_parent (GTR_UPLOAD_DIALOG (upload_dialog));
+  GtrUploadDialog *upload_dialog = ud->dialog;
+  GtkWidget *window = gtr_upload_dialog_get_parent (upload_dialog);
   SoupSession *session = SOUP_SESSION (object);
   SoupStatus status_code = soup_message_get_status (ud->msg);
 
-  GError *error = NULL;
+  g_autoptr (GError) error = NULL;
 
   stream = soup_session_send_finish (session, result, &error);
 
@@ -315,7 +322,7 @@ _upload_file_callback (GObject      *object,
     {
       if (status_code == SOUP_STATUS_FORBIDDEN)
         {
-          dialog = gtk_alert_dialog_new (_("This file has already been uploaded"));
+          dialog = adw_alert_dialog_new (_("This file has already been uploaded"), NULL);
           gtr_tab_enable_upload (active_tab, FALSE);
           goto end;
         }
@@ -323,18 +330,14 @@ _upload_file_callback (GObject      *object,
       g_autofree gchar *message = NULL;
 
       if (error)
-        {
-          message = error->message;
-          g_clear_error (&error);
-        }
+        message = error->message;
       else
-        {
-          message = g_strdup (soup_status_get_phrase (status_code));
-        }
+        message = g_strdup (soup_status_get_phrase (status_code));
 
-      dialog = gtk_alert_dialog_new (
+      dialog = adw_alert_dialog_new (_("Couldn't upload the file"), NULL);
+      adw_alert_dialog_format_body_markup (ADW_ALERT_DIALOG (dialog),
         _(
-          "An error occurred while uploading the file: %s\n"
+          "%s\n"
           "Maybe you've not configured your <i>l10n.gnome.org</i> "
           "<b>token</b> correctly in your profile or you don't have "
           "permissions to upload this module."
@@ -343,15 +346,15 @@ _upload_file_callback (GObject      *object,
       goto end;
     }
 
-  dialog = gtk_alert_dialog_new (_("The file has been uploaded!"));
+  dialog = adw_alert_dialog_new (_("The file has been uploaded!"), NULL);
+  adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+  adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
   gtr_tab_enable_upload (active_tab, FALSE);
 
 end:
-  gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (window));
-  g_object_unref (dialog);
+  adw_dialog_present (dialog, GTK_WIDGET (window));
 
-  gtk_window_destroy (GTK_WINDOW (upload_dialog));
-  g_free (ud);
+  user_data_free (ud);
 }
 
 void
@@ -360,8 +363,8 @@ gtr_upload_file (GtkWidget *upload_dialog,
 {
   GtrTab *tab;
   GtrPo *po;
-  GBytes *bytes;
-  GError *error = NULL;
+  g_autoptr (GBytes) bytes = NULL;
+  g_autoptr (GError) error = NULL;
   GtrProfileManager *pmanager = NULL;
   GtrProfile *profile;
   GtrHeader *header;
@@ -392,10 +395,9 @@ gtr_upload_file (GtkWidget *upload_dialog,
   filename = g_file_get_basename (gtr_po_get_location (po));
   g_file_load_contents (gtr_po_get_location (po), NULL, &content, &size, NULL,
                         &error);
-  if (error != NULL) {
+  if (error != NULL)
     g_warning ("Error opening file %s: %s", filename, (error)->message);
-    g_error_free (error);
-  }
+
   bytes = g_bytes_new (content, size);
   header = gtr_po_get_header (po);
 
@@ -435,7 +437,6 @@ gtr_upload_file (GtkWidget *upload_dialog,
   /* Init multipart container */
   mpart = soup_multipart_new (SOUP_FORM_MIME_TYPE_MULTIPART);
   soup_multipart_append_form_file (mpart, "file", filename, mime_type, bytes);
-  g_bytes_unref (bytes);
   if (upload_comment)
     soup_multipart_append_form_string (mpart, "comment", upload_comment);
 
@@ -454,7 +455,7 @@ gtr_upload_file (GtkWidget *upload_dialog,
 
   UserData *ud;
   ud = g_new0 (UserData, 1);
-  ud->dialog = upload_dialog;
+  ud->dialog = GTR_UPLOAD_DIALOG (upload_dialog);
   ud->msg = msg;
   soup_session_send_async (session, msg, G_PRIORITY_DEFAULT, NULL, _upload_file_callback, ud);
 }
@@ -473,7 +474,7 @@ gtr_upload_file_dialog (GtrWindow * window)
                    G_CALLBACK (gtr_upload_file),
                    window);
 
-  gtk_window_present (GTK_WINDOW (dialog));
+  adw_dialog_present (ADW_DIALOG (dialog), GTK_WIDGET (window));
 }
 
 /*
@@ -491,39 +492,11 @@ gtr_save_file_as_dialog (GtrWindow * window)
   gtk_file_dialog_save (dialog, GTK_WINDOW (window), NULL, save_dialog_response_cb, window);
 }
 
-/*
- * A callback for Save
- */
-void
-gtr_save_current_file_dialog (GtkWidget * widget, GtrWindow * window)
-{
-  GError *error = NULL;
-  GtrTab *current;
-  GtrPo *po;
-
-  current = gtr_window_get_active_tab (window);
-  po = gtr_tab_get_po (current);
-
-  gtr_po_save_file (po, &error);
-
-  if (error)
-    {
-      GtkAlertDialog *dialog = gtk_alert_dialog_new ("%s", error->message);
-      gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (window));
-      g_object_unref (dialog);
-      g_clear_error (&error);
-      return;
-    }
-
-  /* We have to change the state of the tab */
-  gtr_po_set_state (po, GTR_PO_STATE_SAVED);
-}
-
 static void
 load_file_list (GtrWindow * window, const GSList * locations)
 {
   GSList *locations_to_load = NULL;
-  GError *error = NULL;
+  g_autoptr (GError) error = NULL;
 
   g_return_if_fail ((locations != NULL) && (locations->data != NULL));
 
@@ -547,10 +520,10 @@ load_file_list (GtrWindow * window, const GSList * locations)
    */
   if (error != NULL)
     {
-      GtkAlertDialog *dialog = gtk_alert_dialog_new ("%s", error->message);
-      gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (window));
-      g_object_unref (dialog);
-      g_error_free (error);
+      AdwDialog *dialog = adw_alert_dialog_new (NULL, error->message);
+      adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+      adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
+      adw_dialog_present (dialog, GTK_WIDGET (window));
     }
 
   g_slist_free ((GSList *) locations_to_load);
@@ -581,7 +554,7 @@ close_all_tabs (GtrWindow * window)
 static void
 save_and_close_all_documents (GList * unsaved_documents, GtrWindow * window)
 {
-  GError *error = NULL;
+  g_autoptr (GError) error = NULL;
 
   if(unsaved_documents == NULL)
     return;
@@ -589,13 +562,13 @@ save_and_close_all_documents (GList * unsaved_documents, GtrWindow * window)
   gtr_po_save_file (unsaved_documents->data, &error);
 
   if(error)
-  {
-    GtkAlertDialog *dialog = gtk_alert_dialog_new ("%s", error->message);
-    gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (window));
-    g_object_unref (dialog);
-    g_clear_error (&error);
-    return;
-  }
+    {
+      AdwDialog *dialog = adw_alert_dialog_new (NULL, error->message);
+      adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+      adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
+      adw_dialog_present (ADW_DIALOG (dialog), GTK_WIDGET (window));
+      return;
+    }
 
   gtr_window_remove_tab (window);
   gtk_window_destroy (GTK_WINDOW (window));
@@ -613,7 +586,7 @@ close_confirmation_dialog_response_handler (GtrCloseConfirmationDialog *dlg,
       selected_documents = gtr_close_confirmation_dialog_get_selected_documents (dlg);
       if (selected_documents == NULL)
         {
-          gtk_window_destroy (GTK_WINDOW (dlg));
+          adw_dialog_close (ADW_DIALOG (dlg));
           close_all_tabs (window);
           return;
         }
@@ -625,27 +598,23 @@ close_confirmation_dialog_response_handler (GtrCloseConfirmationDialog *dlg,
     }
   else if (g_strcmp0 (response, "no") == 0)
     {
-      gtk_window_destroy (GTK_WINDOW (dlg));
+      adw_dialog_close (ADW_DIALOG (dlg));
       close_all_tabs (window);
       return;
     }
 
-  gtk_window_destroy (GTK_WINDOW (dlg));
+  adw_dialog_close (ADW_DIALOG (dlg));
 }
 
 void
 gtr_close_tab (GtrTab * tab, GtrWindow * window)
 {
-  g_object_set_data (G_OBJECT (window),
-                     GTR_IS_CLOSING_ALL, GINT_TO_POINTER (0));
-
   if (!_gtr_tab_can_close (tab))
     {
       GtkWidget *dlg;
 
       dlg =
-        gtr_close_confirmation_dialog_new_single (GTK_WINDOW (window),
-                                                  gtr_tab_get_po
+        gtr_close_confirmation_dialog_new_single (gtr_tab_get_po
                                                   (tab), FALSE);
 
       g_signal_connect (dlg,
@@ -653,7 +622,7 @@ gtr_close_tab (GtrTab * tab, GtrWindow * window)
                         G_CALLBACK
                         (close_confirmation_dialog_response_handler), window);
 
-      gtk_window_present (GTK_WINDOW (dlg));
+      adw_dialog_present (ADW_DIALOG (dlg), GTK_WIDGET (window));
     }
   else
     //_gtr_window_close_tab (window, tab);
@@ -713,8 +682,7 @@ close_all_documents (GtrWindow * window, gboolean logout_mode)
     {
       GtkWidget *dlg;
 
-      dlg = gtr_close_confirmation_dialog_new (GTK_WINDOW (window),
-                                               list, logout_mode);
+      dlg = gtr_close_confirmation_dialog_new (list, logout_mode);
 
       g_signal_connect (dlg,
                         "response",
@@ -723,7 +691,7 @@ close_all_documents (GtrWindow * window, gboolean logout_mode)
 
       g_list_free (list);
 
-      gtk_window_present (GTK_WINDOW (dlg));
+      adw_dialog_present (ADW_DIALOG (dlg), GTK_WIDGET (window));
     }
   else
     {
@@ -739,9 +707,6 @@ close_all_documents (GtrWindow * window, gboolean logout_mode)
 void
 gtr_file_quit (GtrWindow * window)
 {
-  g_object_set_data (G_OBJECT (window),
-                     GTR_IS_CLOSING_ALL, GINT_TO_POINTER (1));
-
   close_all_documents (window, TRUE);
 }
 
@@ -760,16 +725,16 @@ _gtr_actions_file_save_all (GtrWindow * window)
 
   for (l = list; l != NULL; l = g_list_next (l))
     {
-      GError *error = NULL;
+      g_autoptr (GError) error = NULL;
 
       gtr_po_save_file (GTR_PO (l->data), &error);
 
       if (error)
         {
-          GtkAlertDialog *dialog = gtk_alert_dialog_new ("%s", error->message);
-          gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (window));
-          g_object_unref (dialog);
-          g_clear_error (&error);
+          AdwDialog *dialog = adw_alert_dialog_new (NULL, error->message);
+          adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+          adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
+          adw_dialog_present (ADW_DIALOG (dialog), GTK_WIDGET (window));
 
           return;
         }
