@@ -48,8 +48,6 @@ void gtr_want_to_save_current_dialog (GtrWindow * window, void (*callback)(GtrWi
 
 void gtr_open_file_dialog (GtrWindow * window);
 
-void gtr_save_current_file_dialog (GtkWidget * widget, GtrWindow * window);
-
 void gtr_save_file_as_dialog (GtrWindow * window);
 
 void gtr_upload_file_dialog (GtrWindow * window);
@@ -70,10 +68,6 @@ void _gtr_actions_file_close_all (GtrWindow * window);
 void _gtr_actions_file_save_all (GtrWindow * window);
 
 /*Edit*/
-void gtr_actions_edit_undo (GtrWindow * window);
-
-void gtr_actions_edit_redo (GtrWindow * window);
-
 void gtr_actions_edit_cut (GtrWindow * window);
 
 void gtr_actions_edit_copy (GtrWindow * window);
@@ -83,6 +77,7 @@ void gtr_actions_edit_paste (GtrWindow * window);
 void gtr_actions_edit_header (GtrWindow * window);
 
 void gtr_message_copy_to_translation (GtrWindow * window);
+void gtr_message_copy_original (GtrWindow * window);
 
 void gtr_message_status_toggle_fuzzy (GtrWindow * window);
 
@@ -139,11 +134,7 @@ void search_bar_set_last_options (GtrSearchBar * dialog,
 gboolean run_search (GtrView * view,
                     gboolean follow);
 
-gboolean find_in_list (GtrWindow * window,
-                       GList * views,
-                       gboolean wrap_around,
-                       gboolean search_backwards);
-
+gboolean find_in_list (GtrWindow *window, GtrSearchBar *searchbar);
 
 void do_find (GtrSearchBar * dialog,
               GtrWindow * window,
@@ -155,10 +146,6 @@ void do_replace (GtrSearchBar * dialog,
 void do_replace_all (GtrSearchBar * dialog,
                      GtrWindow * window);
 
-void search_bar_response_cb (GtrSearchBar * dialog,
-                             gint response_id,
-                             GtrWindow    * window);
-
 /*Documents*/
 //void gtr_actions_documents_next_document (GtrWindow * window);
 
