@@ -67,9 +67,6 @@ typedef struct
 {
   GSettings *settings;
   GSettings *window_settings;
-  GtkCssProvider *provider;
-
-  GtrWindow *active_window;
 
   gchar *last_dir;
 
@@ -78,6 +75,15 @@ typedef struct
 
 G_DEFINE_TYPE_WITH_PRIVATE (GtrApplication, gtr_application, ADW_TYPE_APPLICATION)
 
+GtrWindow *gtr_application_create_window (GtrApplication *app);
+
+static GtrWindow *
+get_active_window (GtrApplication *app)
+{
+  return GTR_WINDOW (
+      gtk_application_get_active_window (GTK_APPLICATION (app)));
+}
+
 static gboolean
 ensure_user_config_dir (void)
 {
@@ -110,26 +116,6 @@ on_window_delete_event_cb (GtrWindow * window,
   return TRUE;
 }
 
-static void
-set_active_window (GtrApplication *app,
-                   GtrWindow      *window)
-{
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  priv->active_window = window;
-}
-
-static void
-on_window_destroy_cb (GtrWindow *window, GtrApplication *app)
-{
-  GList *windows;
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-
-  windows = gtk_application_get_windows (GTK_APPLICATION (app));
-
-  if (window == priv->active_window)
-    set_active_window (app, windows != NULL ? windows->data : NULL);
-}
-
 static int
 handle_local_options_cb (GApplication *application, GVariantDict *options, gpointer user_data) {
   if (g_variant_dict_contains (options, "version")) {
@@ -146,7 +132,6 @@ gtr_application_init (GtrApplication *application)
   gchar *profiles_file;
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (application);
 
-  priv->active_window = NULL;
   priv->last_dir = NULL;
   priv->first_run = FALSE;
 
@@ -182,7 +167,6 @@ gtr_application_dispose (GObject * object)
 
   g_clear_object (&priv->settings);
   g_clear_object (&priv->window_settings);
-  g_clear_object (&priv->provider);
 
   G_OBJECT_CLASS (gtr_application_parent_class)->dispose (object);
 }
@@ -207,7 +191,7 @@ new_window_activated (GSimpleAction *action,
   GtrWindow *window;
 
   window = gtr_application_create_window (app);
-  gtk_application_add_window (GTK_APPLICATION (app), GTK_WINDOW (window));
+  gtr_window_show_projects (window);
 }
 
 static void
@@ -216,9 +200,8 @@ find_toggle_activated (GSimpleAction *action,
                        gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
-  gtr_window_toggle_search_bar (priv->active_window);
+  gtr_window_toggle_search_bar (get_active_window (app));
 }
 
 static void
@@ -227,11 +210,10 @@ find_activated (GSimpleAction *action,
                 gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
-  GtrTab *active_tab = gtr_window_get_active_tab (priv->active_window);
+  GtrTab *active_tab = gtr_window_get_active_tab (get_active_window (app));
   g_return_if_fail (active_tab != NULL);
-  gtr_window_show_focus_search_bar (priv->active_window, TRUE);
+  gtr_window_show_focus_search_bar (get_active_window (app), TRUE);
   gtr_tab_find_set_replace (active_tab, FALSE);
 }
 
@@ -241,11 +223,10 @@ find_next_activated (GSimpleAction *action,
                      gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
-  GtrTab *active_tab = gtr_window_get_active_tab (priv->active_window);
+  GtrTab *active_tab = gtr_window_get_active_tab (get_active_window (app));
   g_return_if_fail (active_tab != NULL);
-  gtr_window_show_focus_search_bar (priv->active_window, TRUE);
+  gtr_window_show_focus_search_bar (get_active_window (app), TRUE);
   gtr_tab_find_next (active_tab);
 }
 
@@ -255,11 +236,10 @@ find_prev_activated (GSimpleAction *action,
                      gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
-  GtrTab *active_tab = gtr_window_get_active_tab (priv->active_window);
+  GtrTab *active_tab = gtr_window_get_active_tab (get_active_window (app));
   g_return_if_fail (active_tab != NULL);
-  gtr_window_show_focus_search_bar (priv->active_window, TRUE);
+  gtr_window_show_focus_search_bar (get_active_window (app), TRUE);
   gtr_tab_find_prev (active_tab);
 }
 
@@ -269,10 +249,9 @@ find_and_replace_activated (GSimpleAction *action,
                             gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
-  GtrTab *active_tab = gtr_window_get_active_tab (priv->active_window);
-  gtr_window_show_focus_search_bar (priv->active_window, TRUE);
+  GtrTab *active_tab = gtr_window_get_active_tab (get_active_window (app));
+  gtr_window_show_focus_search_bar (get_active_window (app), TRUE);
   gtr_tab_find_set_replace (active_tab, TRUE);
 }
 
@@ -282,9 +261,18 @@ copy_text_activated (GSimpleAction *action,
                      gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
-  gtr_message_copy_to_translation (priv->active_window);
+  gtr_message_copy_to_translation (get_active_window (app));
+}
+
+static void
+copy_original_activated (GSimpleAction *action,
+                         GVariant      *parameter,
+                         gpointer       user_data)
+{
+  GtrApplication *app = GTR_APPLICATION (user_data);
+
+  gtr_message_copy_original (get_active_window (app));
 }
 
 static void
@@ -293,8 +281,7 @@ preferences_activated (GSimpleAction *action,
                        gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_show_preferences_dialog (priv->active_window);
+  gtr_show_preferences_dialog (get_active_window (app));
 }
 
 static void
@@ -303,8 +290,7 @@ edit_header_activated (GSimpleAction *action,
                        gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_actions_edit_header (priv->active_window);
+  gtr_actions_edit_header (get_active_window (app));
 }
 
 static void
@@ -313,8 +299,7 @@ clear_msgstr_activated (GSimpleAction *action,
                         gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_actions_edit_clear (priv->active_window);
+  gtr_actions_edit_clear (get_active_window (app));
 }
 
 static void
@@ -323,8 +308,7 @@ help_activated (GSimpleAction *action,
                 gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_show_help (GTK_WINDOW (priv->active_window));
+  gtr_show_help (GTK_WINDOW (get_active_window (app)));
 }
 
 static void
@@ -333,8 +317,7 @@ about_activated (GSimpleAction *action,
                  gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_about_dialog (priv->active_window);
+  gtr_about_dialog (get_active_window (app));
 }
 
 static void
@@ -343,15 +326,10 @@ quit_activated (GSimpleAction *action,
                 gpointer       user_data)
 {
   GtkApplication *app = GTK_APPLICATION (user_data);
-  GList *windows, *l;
+  GList *windows;
 
-  // FIXME: this sucks, we need a way to deal with this in a better way
   windows = gtk_application_get_windows (app);
-
-  for (l = windows; l != NULL; l = g_list_next (l))
-    {
-      gtr_file_quit (l->data);
-    }
+  g_list_foreach (windows, (GFunc)gtr_file_quit, NULL);
 }
 
 static void
@@ -360,8 +338,7 @@ upload_file_activated (GSimpleAction *action,
                 gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_upload_file_dialog (priv->active_window);
+  gtr_upload_file_dialog (get_active_window (app));
 }
 
 static void
@@ -370,18 +347,7 @@ saveas_activated (GSimpleAction *action,
                 gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_save_file_as_dialog (priv->active_window);
-}
-
-static void
-save_activated (GSimpleAction *action,
-                GVariant      *parameter,
-                gpointer       user_data)
-{
-  GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_save_current_file_dialog (NULL, priv->active_window);
+  gtr_save_file_as_dialog (get_active_window (app));
 }
 
 static void
@@ -390,8 +356,7 @@ open_activated (GSimpleAction *action,
                 gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_open_file_dialog (priv->active_window);
+  gtr_open_file_dialog (get_active_window (app));
 }
 
 static void
@@ -400,35 +365,15 @@ dl_activated (GSimpleAction *action,
               gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
-  GtrTab *active_tab = gtr_window_get_active_tab (priv->active_window);
+  GtrTab *active_tab = gtr_window_get_active_tab (get_active_window (app));
   GtrPoState state = gtr_po_get_state (gtr_tab_get_po (active_tab));
 
   if (state == GTR_PO_STATE_MODIFIED)
-    gtr_want_to_save_current_dialog (priv->active_window, gtr_window_show_dlteams);
+    gtr_want_to_save_current_dialog (get_active_window (app),
+                                     gtr_window_show_dlteams);
   else
-    gtr_window_show_dlteams (priv->active_window);
-}
-
-static void
-undo_activated (GSimpleAction *action,
-                GVariant      *parameter,
-                gpointer       user_data)
-{
-  GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_actions_edit_undo (priv->active_window);
-}
-
-static void
-redo_activated (GSimpleAction *action,
-                GVariant      *parameter,
-                gpointer       user_data)
-{
-  GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_actions_edit_redo (priv->active_window);
+    gtr_window_show_dlteams (get_active_window (app));
 }
 
 static void
@@ -437,8 +382,7 @@ prev_activated (GSimpleAction *action,
                 gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_message_go_to_previous (priv->active_window);
+  gtr_message_go_to_previous (get_active_window (app));
 }
 
 static void
@@ -447,8 +391,7 @@ next_activated (GSimpleAction *action,
                 gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_message_go_to_next (priv->active_window);
+  gtr_message_go_to_next (get_active_window (app));
 }
 
 static void
@@ -457,8 +400,7 @@ prev_no_activated (GSimpleAction *action,
                    gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_message_go_to_prev_fuzzy_or_untranslated (priv->active_window);
+  gtr_message_go_to_prev_fuzzy_or_untranslated (get_active_window (app));
 }
 
 static void
@@ -467,8 +409,7 @@ next_no_activated (GSimpleAction *action,
                    gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  gtr_message_go_to_next_fuzzy_or_untranslated (priv->active_window);
+  gtr_message_go_to_next_fuzzy_or_untranslated (get_active_window (app));
 }
 
 static void
@@ -477,8 +418,7 @@ build_tm_activated (GSimpleAction *action,
                     gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  GtrWindow *w = GTR_WINDOW (priv->active_window);
+  GtrWindow *w = GTR_WINDOW (get_active_window (app));
   gtr_window_show_tm_dialog (w);
 }
 
@@ -488,8 +428,7 @@ tm_activated (GSimpleAction *action,
               gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  GtrWindow *w = GTR_WINDOW (priv->active_window);
+  GtrWindow *w = GTR_WINDOW (get_active_window (app));
   gtr_window_tm_keybind (w, action);
 }
 
@@ -499,89 +438,51 @@ toggle_fuzzy_activated (GSimpleAction *action,
                         gpointer       user_data)
 {
   GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  GtrWindow *w = GTR_WINDOW (priv->active_window);
+  GtrWindow *w = GTR_WINDOW (get_active_window (app));
   gtr_message_status_toggle_fuzzy (w);
 }
 
-static void
-sort_by_activated (GSimpleAction *action,
-                   GVariant      *parameter,
-                   gpointer       user_data)
-{
-  GtrApplication *app = GTR_APPLICATION (user_data);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  GtrWindow *w;
-  GtrTab *tab;
+static GActionEntry app_entries[]
+    = { { "saveas", saveas_activated, NULL, NULL, NULL },
 
-  GVariant *st;
-  gint sortby = 0;
+        { "upload_file", upload_file_activated, NULL, NULL, NULL },
 
-  g_object_get (G_OBJECT (action), "state", &st, NULL);
-  sortby = g_variant_get_int32 (st);
+        { "open", open_activated, NULL, NULL, NULL },
+        { "dl", dl_activated, NULL, NULL, NULL },
 
-  w = GTR_WINDOW (priv->active_window);
-  if (!w) return;
-  tab = gtr_window_get_active_tab (w);
-  if (!tab) return;
-  gtr_tab_sort_by (tab, (GtrMessageTableSortBy)sortby);
-  gtr_window_hide_sort_menu (w);
-}
+        { "prev", prev_activated, NULL, NULL, NULL },
+        { "next", next_activated, NULL, NULL, NULL },
 
-static GActionEntry app_entries[] = {
-  { "save", save_activated, NULL, NULL, NULL },
-  { "saveas", saveas_activated, NULL, NULL, NULL },
+        { "prev_no", prev_no_activated, NULL, NULL, NULL },
+        { "next_no", next_no_activated, NULL, NULL, NULL },
 
-  { "upload_file", upload_file_activated, NULL, NULL, NULL },
+        { "fuzzy", toggle_fuzzy_activated, NULL, NULL, NULL },
 
-  { "open", open_activated, NULL, NULL, NULL },
-  { "dl", dl_activated, NULL, NULL, NULL },
+        { "build_tm", build_tm_activated, NULL, NULL, NULL },
+        { "tm_1", tm_activated, NULL, NULL, NULL },
+        { "tm_2", tm_activated, NULL, NULL, NULL },
+        { "tm_3", tm_activated, NULL, NULL, NULL },
+        { "tm_4", tm_activated, NULL, NULL, NULL },
+        { "tm_5", tm_activated, NULL, NULL, NULL },
+        { "tm_6", tm_activated, NULL, NULL, NULL },
+        { "tm_7", tm_activated, NULL, NULL, NULL },
+        { "tm_8", tm_activated, NULL, NULL, NULL },
+        { "tm_9", tm_activated, NULL, NULL, NULL },
 
-  { "undo", undo_activated, NULL, NULL, NULL },
-  { "redo", redo_activated, NULL, NULL, NULL },
-
-  { "prev", prev_activated, NULL, NULL, NULL },
-  { "next", next_activated, NULL, NULL, NULL },
-
-  { "prev_no", prev_no_activated, NULL, NULL, NULL },
-  { "next_no", next_no_activated, NULL, NULL, NULL },
-
-  { "fuzzy", toggle_fuzzy_activated, NULL, NULL, NULL },
-
-  // sort actions
-  { "sort_by_id", sort_by_activated, NULL, "0", NULL },
-  { "sort_by_status", sort_by_activated, NULL, "1", NULL },
-  { "sort_by_status_desc", sort_by_activated, NULL, "2", NULL },
-  { "sort_by_msgid", sort_by_activated, NULL, "3", NULL },
-  { "sort_by_msgid_desc", sort_by_activated, NULL, "4", NULL },
-  { "sort_by_translated", sort_by_activated, NULL, "5", NULL },
-  { "sort_by_translated_desc", sort_by_activated, NULL, "6", NULL },
-
-  { "build_tm", build_tm_activated, NULL, NULL, NULL },
-  { "tm_1", tm_activated, NULL, NULL, NULL },
-  { "tm_2", tm_activated, NULL, NULL, NULL },
-  { "tm_3", tm_activated, NULL, NULL, NULL },
-  { "tm_4", tm_activated, NULL, NULL, NULL },
-  { "tm_5", tm_activated, NULL, NULL, NULL },
-  { "tm_6", tm_activated, NULL, NULL, NULL },
-  { "tm_7", tm_activated, NULL, NULL, NULL },
-  { "tm_8", tm_activated, NULL, NULL, NULL },
-  { "tm_9", tm_activated, NULL, NULL, NULL },
-
-  { "copy_text", copy_text_activated, NULL, NULL, NULL },
-  { "find_and_replace", find_and_replace_activated, NULL, NULL, NULL },
-  { "findtoggle", find_toggle_activated, NULL, NULL, NULL },
-  { "find", find_activated, NULL, NULL, NULL },
-  { "find-next", find_next_activated, NULL, NULL, NULL },
-  { "find-prev", find_prev_activated, NULL, NULL, NULL },
-  { "new_window", new_window_activated, NULL, NULL, NULL },
-  { "preferences", preferences_activated, NULL, NULL, NULL },
-  { "edit_header", edit_header_activated, NULL, NULL, NULL },
-  { "clear_msgstr", clear_msgstr_activated, NULL, NULL, NULL },
-  { "help", help_activated, NULL, NULL, NULL },
-  { "about", about_activated, NULL, NULL, NULL },
-  { "quit", quit_activated, NULL, NULL, NULL }
-};
+        { "copy_text", copy_text_activated, NULL, NULL, NULL },
+        { "copy-original", copy_original_activated, NULL, NULL, NULL },
+        { "find_and_replace", find_and_replace_activated, NULL, NULL, NULL },
+        { "findtoggle", find_toggle_activated, NULL, NULL, NULL },
+        { "find", find_activated, NULL, NULL, NULL },
+        { "find-next", find_next_activated, NULL, NULL, NULL },
+        { "find-prev", find_prev_activated, NULL, NULL, NULL },
+        { "new-window", new_window_activated, NULL, NULL, NULL },
+        { "preferences", preferences_activated, NULL, NULL, NULL },
+        { "edit_header", edit_header_activated, NULL, NULL, NULL },
+        { "clear_msgstr", clear_msgstr_activated, NULL, NULL, NULL },
+        { "help", help_activated, NULL, NULL, NULL },
+        { "about", about_activated, NULL, NULL, NULL },
+        { "quit", quit_activated, NULL, NULL, NULL } };
 
 static void
 set_kb (GApplication *app, gchar *action, gchar *accel)
@@ -593,37 +494,26 @@ set_kb (GApplication *app, gchar *action, gchar *accel)
 static void
 gtr_application_startup (GApplication *application)
 {
-  GtrApplication *app = GTR_APPLICATION (application);
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-
   G_APPLICATION_CLASS (gtr_application_parent_class)->startup (application);
   g_set_application_name (_("Translation Editor"));
   gtk_window_set_default_icon_name (PACKAGE_APPID);
 
   gtk_source_init ();
 
-  /* Custom css */
-  priv->provider = gtk_css_provider_new ();
-  gtk_css_provider_load_from_resource (priv->provider, "/org/gnome/translator/styles.css");
-
-  gtk_style_context_add_provider_for_display (gdk_display_get_default (),
-                                              GTK_STYLE_PROVIDER (priv->provider), 600);
-
   g_action_map_add_action_entries (G_ACTION_MAP (application), app_entries,
                                    G_N_ELEMENTS (app_entries), application);
 
   // keybindings
   set_kb (application, "app.open", "<Ctrl>o");
   set_kb (application, "app.dl", "<Ctrl>d");
-  set_kb (application, "app.save", "<Ctrl>s");
+  set_kb (application, "win.save", "<Ctrl>s");
   set_kb (application, "app.saveas", "<Ctrl><Shift>s");
   set_kb (application, "app.upload_file", "<Ctrl>b");
   set_kb (application, "app.preferences", "<Ctrl>comma");
   set_kb (application, "app.help", "F1");
   set_kb (application, "app.quit", "<Primary>q");
+  set_kb (application, "app.new-window", "<Ctrl>n");
 
-  set_kb (application, "app.undo", "<Ctrl>z");
-  set_kb (application, "app.redo", "<Ctrl><Shift>z");
   set_kb (application, "app.clear_msgstr", "<Ctrl>k");
 
   set_kb (application, "app.prev", "<Alt>Left");
@@ -638,6 +528,7 @@ gtr_application_startup (GApplication *application)
   set_kb (application, "app.find-prev", "<Ctrl><Shift>g");
 
   set_kb (application, "app.copy_text", "<Ctrl>space");
+  set_kb (application, "app.copy-original", "<Ctrl><Shift>c");
 
   set_kb (application, "app.build_tm", "<Ctrl>plus");
   set_kb (application, "app.tm_1", "<Ctrl>1");
@@ -674,13 +565,14 @@ gtr_application_setup_window (GApplication *application,
           file_list = g_slist_prepend (file_list, files[i]);
     }
   window = gtr_application_create_window (GTR_APPLICATION (application));
-  gtk_application_add_window (GTK_APPLICATION (application), GTK_WINDOW (window));
 
   /* If it is the first run, the default directory was created in this
    * run, then we show the First run greeter
    */
   if (priv->first_run)
     gtr_window_show_greeter (window);
+  else
+    gtr_window_show_projects (window);
 
   if (file_list != NULL)
     {
@@ -702,6 +594,7 @@ gtr_application_open (GApplication *application,
 static void
 gtr_application_activate (GApplication *application)
 {
+  G_APPLICATION_CLASS (gtr_application_parent_class)->activate (application);
   gtr_application_setup_window (application, NULL, 0);
 }
 
@@ -752,11 +645,14 @@ gtr_application_create_window (GtrApplication *app)
   GdkToplevelState state;
   gint w, h;
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
+  GtkWindowGroup *group;
 
+  group = gtk_window_group_new ();
   g_return_val_if_fail (GTR_IS_APPLICATION (app), NULL);
 
   window = g_object_new (GTR_TYPE_WINDOW, "application", app, NULL);
-  set_active_window (app, window);
+  gtk_window_group_add_window (group, GTK_WINDOW (window));
+  g_object_unref (group);
 
   state = g_settings_get_int (priv->window_settings,
                               GTR_SETTINGS_WINDOW_STATE);
@@ -766,7 +662,6 @@ gtr_application_create_window (GtrApplication *app)
                   "(ii)", &w, &h);
 
   gtk_window_set_default_size (GTK_WINDOW (window), w, h);
-  gtk_application_window_set_show_menubar (GTK_APPLICATION_WINDOW (window), FALSE);
 
   if ((state & GDK_TOPLEVEL_STATE_MAXIMIZED) != 0)
     gtk_window_maximize (GTK_WINDOW (window));
@@ -776,9 +671,6 @@ gtr_application_create_window (GtrApplication *app)
   g_signal_connect (window, "close-request",
                     G_CALLBACK (on_window_delete_event_cb), app);
 
-  g_signal_connect (window, "destroy",
-                    G_CALLBACK (on_window_destroy_cb), app);
-
   gtk_window_present (GTK_WINDOW (window));
 
   return window;
@@ -800,13 +692,12 @@ gtr_application_get_views (GtrApplication * app,
                            gboolean original, gboolean translated)
 {
   GList *res = NULL;
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
 
   g_return_val_if_fail (GTR_IS_APPLICATION (app), NULL);
 
-  res = g_list_concat (res,
-                       gtr_window_get_all_views (GTR_WINDOW (priv->active_window),
-                                                 original, translated));
+  res = g_list_concat (
+      res, gtr_window_get_all_views (GTR_WINDOW (get_active_window (app)),
+                                     original, translated));
 
   return res;
 }
@@ -820,10 +711,9 @@ gtr_application_get_views (GtrApplication * app,
 GtrWindow *
 gtr_application_get_active_window (GtrApplication * app)
 {
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
   g_return_val_if_fail (GTR_IS_APPLICATION (app), NULL);
 
-  return GTR_WINDOW (priv->active_window);
+  return get_active_window (app);
 }
 
 /**
@@ -853,14 +743,6 @@ _gtr_application_set_last_dir (GtrApplication * app, const gchar * last_dir)
   GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
   g_return_if_fail (GTR_IS_APPLICATION (app));
 
+  g_clear_pointer (&priv->last_dir, g_free);
   priv->last_dir = g_strdup (last_dir);
 }
-
-GSettings *
-_gtr_application_get_settings (GtrApplication *app)
-{
-  GtrApplicationPrivate *priv = gtr_application_get_instance_private (app);
-  g_return_val_if_fail (GTR_IS_APPLICATION (app), NULL);
-
-  return priv->settings;
-}
