@@ -35,9 +35,6 @@
 
 typedef struct
 {
-  GtkWidget *titlebar;
-  GtkWidget *main_box;
-  GtkWidget *open_button;
   GtkWidget *load_button;
   GtkWidget *reserve_button;
   GtkWidget *stats_label;
@@ -68,10 +65,10 @@ typedef struct
 
 struct _GtrDlTeams
 {
-  AdwBin parent_instance;
+  AdwNavigationPage parent_instance;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (GtrDlTeams, gtr_dl_teams, ADW_TYPE_BIN)
+G_DEFINE_TYPE_WITH_PRIVATE (GtrDlTeams, gtr_dl_teams, ADW_TYPE_NAVIGATION_PAGE)
 
 typedef struct
 {
@@ -86,7 +83,6 @@ struct _GtrDlTeamsDomain
 
 G_DEFINE_TYPE_WITH_PRIVATE (GtrDlTeamsDomain, gtr_dl_teams_domain, G_TYPE_OBJECT)
 
-static void team_add_cb (GtkButton *btn, GtrDlTeams *self);
 static void gtr_dl_teams_save_combo_selected (GtkWidget *widget, GParamSpec *spec, GtrDlTeams *self);
 static void gtr_dl_teams_load_po_file (GtkButton *button, GtrDlTeams *self);
 static void gtr_dl_teams_get_file_info (GtrDlTeams *self);
@@ -143,22 +139,24 @@ gtr_dl_teams_parse_teams_json (GObject *object,
   const char *def_lang = NULL;
   unsigned int def_lang_pos = 0;
   GtrProfile *profile = NULL;
-  GError *error = NULL;
+  g_autoptr (GError) error = NULL;
   JsonNode *node = NULL;
   JsonArray *array = NULL;
 
   GtrDlTeams *widget = GTR_DL_TEAMS (user_data);
   GtrDlTeamsPrivate *priv = gtr_dl_teams_get_instance_private (widget);
 
-  GtkAlertDialog *dialog;
+  AdwDialog *dialog;
 
   /* Parse JSON */
   stream = soup_session_send_finish (SOUP_SESSION (object), result, &error);
 
   if (error)
     {
-      dialog = gtk_alert_dialog_new ("%s", error->message);
-      gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (priv->main_window));
+      dialog = adw_alert_dialog_new (NULL, error->message);
+      adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+      adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
+      adw_dialog_present (ADW_DIALOG (dialog), GTK_WIDGET (priv->main_window));
       return;
     }
 
@@ -206,7 +204,7 @@ gtr_dl_teams_load_module_details_json (GtkWidget  *widget,
   JsonObject *object;
   JsonNode *branchesNode;
   JsonNode *domainsNode;
-  GtkAlertDialog *dialog;
+  AdwDialog *dialog;
   SoupStatus status_code;
   g_autoptr(GInputStream) stream = NULL;
 
@@ -248,8 +246,10 @@ gtr_dl_teams_load_module_details_json (GtkWidget  *widget,
           message = g_strdup (soup_message_get_reason_phrase (msg));
         }
 
-      dialog = gtk_alert_dialog_new (_("Error loading module info: %s"), message);
-      gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (priv->main_window));
+      dialog = adw_alert_dialog_new (_("Error loading module info"), message);
+      adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+      adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
+      adw_dialog_present (dialog, GTK_WIDGET (priv->main_window));
       return;
     }
 
@@ -318,7 +318,7 @@ gtr_dl_teams_parse_modules_json (GObject *object,
 {
   g_autoptr(JsonParser) parser = json_parser_new ();
   g_autoptr(GInputStream) stream = NULL;
-  GError *error = NULL;
+  g_autoptr (GError) error = NULL;
 
   JsonNode *node = NULL;
   JsonArray *array = NULL;
@@ -326,14 +326,16 @@ gtr_dl_teams_parse_modules_json (GObject *object,
   GtrDlTeams *widget = GTR_DL_TEAMS (user_data);
   GtrDlTeamsPrivate *priv = gtr_dl_teams_get_instance_private (widget);
 
-  GtkAlertDialog *dialog;
+  AdwDialog *dialog;
 
   /* Parse JSON */
   stream = soup_session_send_finish (SOUP_SESSION (object), result, &error);
   if (error)
     {
-      dialog = gtk_alert_dialog_new ("%s", error->message);
-      gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (priv->main_window));
+      dialog = adw_alert_dialog_new (NULL, error->message);
+      adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+      adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
+      adw_dialog_present (ADW_DIALOG (dialog), GTK_WIDGET (priv->main_window));
       return;
     }
 
@@ -404,7 +406,7 @@ gtr_dl_teams_get_file_info (GtrDlTeams *self)
   JsonObject *stats_object;
   const char *format;
   char *markup;
-  GtkAlertDialog *dialog;
+  AdwDialog *dialog;
   SoupStatus status_code;
   g_autoptr(GInputStream) stream = NULL;
 
@@ -438,8 +440,10 @@ gtr_dl_teams_get_file_info (GtrDlTeams *self)
           message = g_strdup (soup_message_get_reason_phrase (msg));
         }
 
-      dialog = gtk_alert_dialog_new (_("Error loading file info: %s"), message);
-      gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (priv->main_window));
+      dialog = adw_alert_dialog_new (_("Error loading file info"), message);
+      adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+      adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
+      adw_dialog_present (dialog, GTK_WIDGET (priv->main_window));
       return;
     }
 
@@ -510,22 +514,24 @@ gtr_dl_teams_load_po_file (GtkButton *button, GtrDlTeams *self)
   GtrDlTeamsPrivate *priv = gtr_dl_teams_get_instance_private (self);
   g_autoptr(SoupMessage) msg = NULL;
   GError *error = NULL;
-  GFile *tmp_file = NULL;
+  g_autoptr (GFile) tmp_file = NULL;
   GFileIOStream *iostream = NULL;
   GOutputStream *output = NULL;
-  GtkAlertDialog *dialog;
+  AdwDialog *dialog;
   gboolean ret = FALSE;
   int file_index = 0;
   const char *dest_dir = g_get_user_special_dir (G_USER_DIRECTORY_DOWNLOAD);
   g_autofree char *basename = NULL;
+  g_autofree char *og_basename = NULL;
   g_autofree char *file_path = NULL;
   g_autoptr(GFile) dest_file = NULL;
   gboolean reserve_first = FALSE;
   SoupStatus status_code;
-  GBytes *bytes;
+  g_autoptr (GBytes) bytes = NULL;
 
   // reserve for translation first
-  reserve_first = gtk_switch_get_active (GTK_SWITCH (priv->reserve_button));
+  reserve_first
+      = adw_switch_row_get_active (ADW_SWITCH_ROW (priv->reserve_button));
   if (reserve_first)
     {
       ret = gtr_dl_teams_reserve_for_translation (priv->reserve_button, self);
@@ -559,8 +565,10 @@ gtr_dl_teams_load_po_file (GtkButton *button, GtrDlTeams *self)
           message = g_strdup (soup_message_get_reason_phrase (msg));
         }
 
-      dialog = gtk_alert_dialog_new (_("Error loading file: %s"), message);
-      gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (priv->main_window));
+      dialog = adw_alert_dialog_new (_("Error loading file"), message);
+      adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+      adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
+      adw_dialog_present (dialog, GTK_WIDGET (priv->main_window));
       return;
     }
 
@@ -568,29 +576,31 @@ gtr_dl_teams_load_po_file (GtkButton *button, GtrDlTeams *self)
 
   if (error != NULL)
     {
-      dialog = gtk_alert_dialog_new (_("Error creating tmp file: %s"), error->message);
-      gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (priv->main_window));
+      dialog = adw_alert_dialog_new (_("Error creating tmp file"),
+                                     error->message);
+      adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+      adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
+      adw_dialog_present (dialog, GTK_WIDGET (priv->main_window));
       g_error_free (error);
       return;
     }
 
   output = g_io_stream_get_output_stream (G_IO_STREAM (iostream));
-  g_output_stream_write_bytes (output,
-                               bytes,
-                               NULL,
-                               &error);
-  g_bytes_unref (bytes);
+  g_output_stream_write_bytes (output, bytes, NULL, &error);
 
   if (error != NULL)
     {
-      dialog = gtk_alert_dialog_new (_("Error writing stream: %s"), error->message);
-      gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (priv->main_window));
+      dialog = adw_alert_dialog_new (_("Error writing stream"), error->message);
+      adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+      adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
+      adw_dialog_present (dialog, GTK_WIDGET (priv->main_window));
       g_error_free (error);
       return;
     }
 
   /* Save file to Downloads; file basename is the part from last / character on */
   basename = g_path_get_basename (priv->file_path);
+  og_basename = g_strdup (basename);
   // Remove the extension
   file_path = g_strconcat ("file://", dest_dir, "/", basename, NULL);
   dest_file = g_file_new_for_uri (file_path);
@@ -598,7 +608,7 @@ gtr_dl_teams_load_po_file (GtkButton *button, GtrDlTeams *self)
   ret = g_file_copy (tmp_file, dest_file, G_FILE_COPY_NONE, NULL, NULL, NULL, &error);
   while (!ret && g_error_matches (error, G_IO_ERROR, G_IO_ERROR_EXISTS))
     {
-      g_autofree char *tmpname = gtr_utils_get_filename (basename);
+      g_autofree char *tmpname = gtr_utils_get_filename (og_basename);
       g_free (basename);
       g_free (file_path);
       g_object_unref (dest_file);
@@ -612,32 +622,28 @@ gtr_dl_teams_load_po_file (GtkButton *button, GtrDlTeams *self)
 
   if (error != NULL)
     {
-      dialog = gtk_alert_dialog_new (_("Error creating tmp file: %s"), error->message);
-      gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (priv->main_window));
+      dialog = adw_alert_dialog_new (_("Error creating tmp file"), error->message);
+      adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+      adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
+      adw_dialog_present (dialog, GTK_WIDGET (priv->main_window));
       g_error_free (error);
       return;
     }
 
-  if (gtr_open (dest_file, priv->main_window, &error)) {
-    GtrTab *tab = gtr_window_get_active_tab (priv->main_window);
-    g_autofree char *info_msg = NULL;
-    info_msg = g_strdup_printf (_("The file '%s' has been saved in %s"),
-                                basename, dest_dir);
-    gtr_tab_set_info (tab, info_msg, NULL);
+  if (gtr_open (dest_file, priv->main_window, &error))
+    {
+      GtrTab *tab = gtr_window_get_active_tab (priv->main_window);
+      g_info ("The file '%s' has been saved in '%s'", basename, dest_dir);
+      gtr_tab_set_info (tab, _("The file has been saved in your Downloads folder"), NULL);
 
-    GtrPo *po = gtr_tab_get_po(tab);
-    GError *po_error = NULL;
-    gtr_po_set_dl_info(po,
-                       priv->selected_lang,
-                       priv->selected_module,
-                       priv->selected_branch,
-                       priv->selected_domain,
-                       priv->module_state);
-    // Save to update the headers
-    gtr_po_save_file(po, &po_error);
-  }
-
-  g_object_unref (tmp_file);
+      GtrPo *po = gtr_tab_get_po (tab);
+      g_autoptr (GError) po_error = NULL;
+      gtr_po_set_dl_info (po, priv->selected_lang, priv->selected_module,
+                          priv->selected_branch, priv->selected_domain,
+                          priv->module_state);
+      // Save to update the headers
+      gtr_po_save_file (po, &po_error);
+    }
 }
 
 /* Reserve for translation */
@@ -647,10 +653,10 @@ gtr_dl_teams_reserve_for_translation (GtkWidget *button, GtrDlTeams *self)
   GtrDlTeamsPrivate *priv = gtr_dl_teams_get_instance_private (self);
   GtrProfileManager *pmanager = NULL;
   GtrProfile *profile = NULL;
-  GtkAlertDialog *dialog;
+  AdwDialog *dialog;
   const char *auth_token = NULL;
   SoupStatus status_code;
-  GError *error = NULL;
+  g_autoptr (GError) error = NULL;
 
   g_autoptr (SoupMessage) msg = NULL;
   g_autoptr(GInputStream) stream = NULL;
@@ -681,37 +687,28 @@ gtr_dl_teams_reserve_for_translation (GtkWidget *button, GtrDlTeams *self)
   if (error || !SOUP_STATUS_IS_SUCCESSFUL (status_code))
   {
     if (error)
-      {
-        message = error->message;
-        g_clear_error (&error);
-      }
+      message = error->message;
     else
-      {
-        message = g_strdup (soup_message_get_reason_phrase (msg));
-      }
+      message = g_strdup (soup_message_get_reason_phrase (msg));
 
-    dialog = gtk_alert_dialog_new (
+    dialog = adw_alert_dialog_new (_("Could not reserve module"), NULL);
+    adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+    adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
+    adw_alert_dialog_format_body (ADW_ALERT_DIALOG (dialog),
       _(
-        "An error occurred while reserving this module: %s\n"
+        "%s\n"
         "Maybe you've not configured your l10n.gnome.org "
         "token correctly in your profile or you don't have "
         "permissions to reserve this module."
       ),
       message);
-    gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (priv->main_window));
+    adw_dialog_present (dialog, GTK_WIDGET (priv->main_window));
     return FALSE;
   }
 
-  /* Display a message if the reserve for translation operation was successful */
-  message = g_strdup_printf (
-    _("The file '%s.%s.%s.%s' has been successfully reserved"),
-    priv->selected_module,
-    priv->selected_branch,
-    priv->selected_lang,
-    priv->selected_domain);
-
   gtk_widget_set_sensitive (priv->reserve_button, FALSE);
-  gtr_window_add_toast_msg (GTR_WINDOW (priv->main_window), message);
+  gtr_window_add_toast_msg (GTR_WINDOW (priv->main_window),
+                            _("The file has been successfully reserved"));
 
   return TRUE;
 }
@@ -842,16 +839,12 @@ gtr_dl_teams_class_init (GtrDlTeamsClass *klass)
   gtk_widget_class_set_template_from_resource (widget_class,
                                                "/org/gnome/translator/gtr-dl-teams.ui");
 
-  gtk_widget_class_bind_template_child_private (widget_class, GtrDlTeams, titlebar);
-  gtk_widget_class_bind_template_child_private (widget_class, GtrDlTeams, main_box);
   gtk_widget_class_bind_template_child_private (widget_class, GtrDlTeams, file_label);
   gtk_widget_class_bind_template_child_private (widget_class, GtrDlTeams, stats_label);
   gtk_widget_class_bind_template_child_private (widget_class, GtrDlTeams, module_state_label);
   gtk_widget_class_bind_template_child_private (widget_class, GtrDlTeams, load_button);
   gtk_widget_class_bind_template_child_private (widget_class, GtrDlTeams, reserve_button);
 
-  gtk_widget_class_bind_template_child_private (widget_class, GtrDlTeams, open_button);
-
   gtk_widget_class_bind_template_child_private (widget_class, GtrDlTeams, langs_combobox);
   gtk_widget_class_bind_template_child_private (widget_class, GtrDlTeams, modules_combobox);
   gtk_widget_class_bind_template_child_private (widget_class, GtrDlTeams, domains_combobox);
@@ -910,13 +903,10 @@ gtr_dl_teams_init (GtrDlTeams *self)
   );
   gtk_drop_down_set_expression (GTK_DROP_DOWN (priv->modules_combobox), expression);
   gtk_drop_down_set_enable_search (GTK_DROP_DOWN (priv->modules_combobox), TRUE);
+  gtk_drop_down_set_search_match_mode (GTK_DROP_DOWN (priv->modules_combobox),
+                                       GTK_STRING_FILTER_MATCH_MODE_SUBSTRING);
   gtk_widget_set_sensitive (priv->modules_combobox, FALSE);
 
-  g_signal_connect (priv->open_button,
-                    "clicked",
-                    G_CALLBACK (team_add_cb),
-                    self);
-
   /* Connect "changed" to all combo boxes */
   g_signal_connect (priv->langs_combobox,
                     "notify::selected",
@@ -959,23 +949,6 @@ gtr_dl_teams_new (GtrWindow *window)
   return self;
 }
 
-GtkWidget *
-gtr_dl_teams_get_header (GtrDlTeams *self)
-{
-  GtrDlTeamsPrivate *priv = gtr_dl_teams_get_instance_private (self);
-  return priv->titlebar;
-}
-
-// static functions
-static void
-team_add_cb (GtkButton   *btn,
-             GtrDlTeams *self)
-{
-  GtrDlTeamsPrivate *priv = gtr_dl_teams_get_instance_private (self);
-  GtrWindow *window = GTR_WINDOW (priv->main_window);
-  gtr_open_file_dialog (window);
-}
-
 // Domains GObject
 GtrDlTeamsDomain*
 gtr_dl_teams_domain_new (const char *name, const char *description)
