@@ -64,10 +64,10 @@ typedef struct
 
 struct _GtrHeaderDialog
 {
-  AdwPreferencesWindow parent_instance;
+  AdwPreferencesDialog parent_instance;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (GtrHeaderDialog, gtr_header_dialog, ADW_TYPE_PREFERENCES_WINDOW)
+G_DEFINE_TYPE_WITH_PRIVATE (GtrHeaderDialog, gtr_header_dialog, ADW_TYPE_PREFERENCES_DIALOG)
 
 static void
 gtr_header_dialog_dispose (GObject * object)
@@ -115,14 +115,13 @@ gtr_header_dialog_class_init (GtrHeaderDialogClass * klass)
 }
 
 static void
-take_my_options_checkbutton_toggled (GtkSwitch *button,
-                                     GParamSpec *spec,
+take_my_options_checkbutton_toggled (AdwSwitchRow *button, GParamSpec *spec,
                                      GtrHeaderDialog *dlg)
 {
   gboolean active;
   GtrHeaderDialogPrivate *priv = gtr_header_dialog_get_instance_private (dlg);
 
-  active = gtk_switch_get_active (button);
+  active = adw_switch_row_get_active (button);
 
   g_settings_set_boolean (priv->settings, GTR_SETTINGS_USE_PROFILE_VALUES,
                           active);
@@ -343,14 +342,14 @@ gtr_header_dialog_init (GtrHeaderDialog * dlg)
 
   priv->settings = g_settings_new ("org.gnome.gtranslator.preferences.files");
 
-  gtk_window_set_title (GTK_WINDOW (dlg), _("Edit Header"));
-  gtk_window_set_destroy_with_parent (GTK_WINDOW (dlg), TRUE);
-  gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
+  adw_dialog_set_title (ADW_DIALOG (dlg), _("Edit Header"));
 
   gtk_widget_init_template (GTK_WIDGET (dlg));
 
-  gtk_switch_set_active (GTK_SWITCH (priv->take_my_options),
-                         g_settings_get_boolean (priv->settings, GTR_SETTINGS_USE_PROFILE_VALUES));
+  adw_switch_row_set_active (
+      ADW_SWITCH_ROW (priv->take_my_options),
+      g_settings_get_boolean (priv->settings,
+                              GTR_SETTINGS_USE_PROFILE_VALUES));
 
   gtk_text_view_set_editable (GTK_TEXT_VIEW (priv->prj_comment), TRUE);
 
@@ -359,12 +358,12 @@ gtr_header_dialog_init (GtrHeaderDialog * dlg)
   gtk_widget_set_sensitive (priv->charset, FALSE);
   gtk_widget_set_sensitive (priv->state, FALSE);
 
-  if (gtk_switch_get_active (GTK_SWITCH (priv->take_my_options)))
+  if (adw_switch_row_get_active (ADW_SWITCH_ROW (priv->take_my_options)))
     {
       gboolean active;
 
-      active =
-        gtk_switch_get_active (GTK_SWITCH (priv->take_my_options));
+      active
+          = adw_switch_row_get_active (ADW_SWITCH_ROW (priv->take_my_options));
 
       gtk_widget_set_sensitive (priv->translator, !active);
       gtk_widget_set_sensitive (priv->tr_email, !active);
@@ -387,8 +386,6 @@ set_default_values (GtrHeaderDialog * dlg, GtrWindow * window)
   priv->po = gtr_tab_get_po (tab);
   gtr_header_dialog_fill_from_header (GTR_HEADER_DIALOG (dlg));
 
-  gtk_window_set_transient_for (GTK_WINDOW (dlg), GTK_WINDOW (window));
-
   /*Connect signals */
   g_signal_connect (priv->take_my_options, "notify::active",
                     G_CALLBACK (take_my_options_checkbutton_toggled), dlg);
@@ -445,7 +442,5 @@ gtr_show_header_dialog (GtrWindow * window)
   dlg = GTK_WIDGET (g_object_new (GTR_TYPE_HEADER_DIALOG, NULL));
   set_default_values (GTR_HEADER_DIALOG (dlg), window);
 
-  gtk_window_set_transient_for (GTK_WINDOW (dlg), GTK_WINDOW (window));
-  gtk_window_set_modal (GTK_WINDOW (dlg), TRUE);
-  gtk_window_present (GTK_WINDOW (dlg));
+  adw_dialog_present (ADW_DIALOG (dlg), GTK_WIDGET (window));
 }
