@@ -130,14 +130,6 @@ enum
   PROP_STATE
 };
 
-enum
-{
-  FILE_INCONSISTENT_WITH_PROFILE,
-  NO_OF_SIGNALS
-};
-
-static guint signals[NO_OF_SIGNALS];
-
 static gchar *message_error = NULL;
 
 static void
@@ -332,22 +324,10 @@ gtr_po_class_init (GtrPoClass * klass)
                                                         G_TYPE_FILE,
                                                         G_PARAM_READWRITE));
 
-  g_object_class_install_property (object_class,
-                                   PROP_STATE,
-                                   g_param_spec_enum ("state",
-                                                      "State",
-                                                      "The po's state",
-                                                      GTR_TYPE_PO_STATE,
-                                                      GTR_PO_STATE_SAVED,
-                                                      G_PARAM_READABLE));
-  /* Signals */
-  signals[FILE_INCONSISTENT_WITH_PROFILE] =
-    g_signal_new ("file-is-inconsistent-with-profile",
-                  G_OBJECT_CLASS_TYPE (klass),
-                  G_SIGNAL_RUN_LAST,
-                  0, NULL, NULL,
-                  g_cclosure_marshal_VOID__VOID,
-                  G_TYPE_NONE, 0);
+  g_object_class_install_property (
+      object_class, PROP_STATE,
+      g_param_spec_enum ("state", "State", "The po's state", GTR_TYPE_PO_STATE,
+                         GTR_PO_STATE_SAVED, G_PARAM_READABLE));
 }
 
 /*
@@ -1007,15 +987,6 @@ void gtr_po_set_dl_info (GtrPo * po, gchar * lang, gchar * module_name,
   if (module_state)
     gtr_header_set_field (priv->header, "X-DL-State", module_state);
 }
-/*
- * FIXME: We are not using this func.
- */
-gboolean
-gtr_po_get_write_perms (GtrPo * po)
-{
-  GtrPoPrivate *priv = gtr_po_get_instance_private (po);
-  return priv->no_write_perms;
-}
 
 /**
  * gtr_po_get_messages:
@@ -1033,23 +1004,6 @@ gtr_po_get_messages (GtrPo * po)
   return priv->messages;
 }
 
-/* FIXME: this is hack, we should fix it */
-/**
- * gtr_po_set_messages:
- * @po: a #GtrPo
- * @messages: (element-type Gtranslator.Msg): a pointer to a new messages list.
- *
- * Sets an updated list of messages.
- **/
-void
-gtr_po_set_messages (GtrPo * po, GList * messages)
-{
-  GtrPoPrivate *priv = gtr_po_get_instance_private (po);
-  g_return_if_fail (GTR_IS_PO (po));
-
-  priv->messages = messages;
-}
-
 /**
  * gtr_po_get_current_message:
  * @po: a #GtrPo
@@ -1427,35 +1381,6 @@ gtr_po_check_po_file (GtrPo * po)
   return message_error;
 }
 
-/**
- * gtr_po_consistent_with_profile
- * @po: a #GtrPo
- *
- * Tests whether the po file is consistent or not with profile values
- * Returns: If the po file is not consistent with profile then it returns 0 .
- **/
-gboolean
-gtr_po_consistent_with_profile (GtrPo * po)
-{
-  GtrProfileManager *prof_manager;
-  GtrProfile *profile;
-  gint po_header_nplurals;
-  gint profile_nplurals = -1;
-
-  GtrHeader *header = gtr_po_get_header (po);
-  po_header_nplurals = gtr_header_get_nplurals (header);
-
-  prof_manager = gtr_profile_manager_get_default ();
-  profile = gtr_profile_manager_get_active_profile (prof_manager);
-  profile_nplurals = parse_nplurals_header (
-    gtr_profile_get_plural_forms (profile)
-  );
-
-  g_object_unref (prof_manager);
-
-  return profile_nplurals == po_header_nplurals;
-}
-
 const gchar *
 gtr_po_get_dl_lang (GtrPo *po)
 {
@@ -1497,9 +1422,3 @@ gtr_po_can_dl_upload (GtrPo *po)
   GtrPoPrivate *priv = gtr_po_get_instance_private (po);
   return g_strcmp0 (priv->dl_state, "Translating") == 0;
 }
-
-void
-gtr_po_emit_file_not_consistent (GtrPo *po)
-{
-  g_signal_emit (G_OBJECT(po), signals[FILE_INCONSISTENT_WITH_PROFILE], 0);
-}
