@@ -25,10 +25,10 @@ G_BEGIN_DECLS
 
 #define GTR_TYPE_PROJECTS (gtr_projects_get_type())
 
-G_DECLARE_FINAL_TYPE (GtrProjects, gtr_projects, GTR, PROJECTS, AdwBin)
+G_DECLARE_FINAL_TYPE (GtrProjects, gtr_projects, GTR, PROJECTS,
+                      AdwNavigationPage)
 
 GtrProjects*  gtr_projects_new         ();
-GtkWidget*    gtr_projects_get_header  (GtrProjects *self);
 void          gtr_projects_recent_add  (GtrProjects *self,
                                         GFile *location,
                                         gchar *jkkproject_id);
