@@ -83,9 +83,7 @@ typedef struct
   GtkWidget *dock;
   GtkWidget *window;
 
-  /* Flap state */
-  AdwFlap *hbox;
-  gboolean flap_state;
+  AdwOverlaySplitView *overlay_split_view;
 
   GtkWidget *message_table;
   GtkWidget *context;
@@ -108,7 +106,6 @@ typedef struct
   GtkWidget *untranslated;
 
   /* Autosave */
-  GTimer *timer;
   gint autosave_interval;
   guint autosave_timeout;
   guint autosave : 1;
@@ -123,22 +120,12 @@ typedef struct
   GtrSearchBar   *gtr_search_bar;
 
   /* notebook code */
-  GtkWidget *titlebar;
-  GtkWidget *save;
-  GtkWidget *sort_id;
-  GtkWidget *sort_status;
-  GtkWidget *sort_msgid;
-  GtkWidget *sort_translated;
-  GtkWidget *order_menu_popover;
   GtkWidget *search_toggle;
   GtkWidget *upload;
 
-  GtkWidget *undo;
-  GtkWidget *redo;
-
 } GtrTabPrivate;
 
-G_DEFINE_TYPE_WITH_PRIVATE (GtrTab, gtr_tab, GTK_TYPE_BOX)
+G_DEFINE_TYPE_WITH_PRIVATE (GtrTab, gtr_tab, ADW_TYPE_BIN)
 
 enum
 {
@@ -184,7 +171,7 @@ gtr_tab_focus_search_bar (GtrTab *tab)
   g_assert (GTR_IS_TAB (tab));
   priv = gtr_tab_get_instance_private (tab);
 
-  entry = (GtkEntry *) gtr_search_bar_get_search (priv->gtr_search_bar);
+  entry = gtr_search_bar_get_search (priv->gtr_search_bar);
 
   gtk_entry_grab_focus_without_selecting (entry);
 }
@@ -277,67 +264,6 @@ msg_grab_focus (GtrTab *tab)
   return FALSE;
 }
 
-static void
-handle_file_is_inconsistent (GtrPo *po, GtrTab *tab)
-{
-  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
-  GtrProfileManager *manager = gtr_profile_manager_get_default ();
-  GtrProfile *active_profile = gtr_profile_manager_get_active_profile (manager);
-  const char *profile_name = gtr_profile_get_name (active_profile);
-  int profile_nplurals = -1;
-  int po_nplurals = -1;
-
-  g_autofree char *info_msg_primary = NULL;
-  g_autofree char *info_msg_secondary = NULL;
-  g_autofree char *filename = NULL;
-  g_autoptr (GFile) po_file = gtr_po_get_location (po);
-
-  filename = g_file_get_path (po_file);
-  po_nplurals = gtr_header_get_nplurals (gtr_po_get_header (po));
-  profile_nplurals = parse_nplurals_header (gtr_profile_get_plural_forms (active_profile));
-
-  info_msg_primary = g_strdup_printf (_("File is not consistent with profile %s"), profile_name);
-  info_msg_secondary = g_strdup_printf (_(
-    "File nplurals: %d, is different from profile nplurals %d.\n"
-    "Kindly go to preferences and select a profile with consistent nplurals "
-    "values as this file %s."),
-    po_nplurals, profile_nplurals, filename
-  );
-  gtr_tab_set_info (tab, info_msg_primary, info_msg_secondary);
-
-  GtkWidget *nb = priv->trans_notebook;
-  gtk_widget_set_sensitive (nb, FALSE);
-
-  g_object_unref (manager);
-}
-
-static void
-on_active_profile_changed (GtrProfileManager *manager, GtrProfile *profile, GtrTab *tab)
-{
-  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
-  GtkWidget *nb = priv->trans_notebook;
-
-  GtrPo *po = priv->po;
-  if (!gtr_po_consistent_with_profile (po))
-  {
-    gtr_po_emit_file_not_consistent (po);
-  }
-  else
-  {
-    gtk_widget_set_sensitive (nb, TRUE);
-  }
-}
-
-static void
-on_profile_modified (GtrProfileManager *manager,
-                     GtrProfile *old_profile,
-                     GtrProfile *new_profile,
-                     GtrTab *tab)
-{
-  on_active_profile_changed (manager, new_profile, tab);
-}
-
-
 static void
 install_autosave_timeout (GtrTab * tab)
 {
@@ -377,7 +303,7 @@ install_autosave_timeout_if_needed (GtrTab * tab)
 static gboolean
 gtr_tab_autosave (GtrTab * tab)
 {
-  GError *error = NULL;
+  g_autoptr (GError) error = NULL;
   GtrTabPrivate *priv;
 
   priv = gtr_tab_get_instance_private (tab);
@@ -386,10 +312,7 @@ gtr_tab_autosave (GtrTab * tab)
 
   gtr_po_save_file (priv->po, &error);
   if (error)
-    {
-      g_warning ("%s", error->message);
-      g_error_free (error);
-    }
+    g_warning ("%s", error->message);
 
   return TRUE;
 }
@@ -418,11 +341,13 @@ gtr_tab_edition_finished (GtrTab * tab, GtrMsg * msg)
 
   if (message_error != NULL)
     {
-      g_autoptr (GtkAlertDialog) dialog = gtk_alert_dialog_new (_("There is an error in the message:"));
+      AdwDialog *dialog = adw_alert_dialog_new (
+        _("There is an error in the message"), message_error);
 
       gtr_tab_block_movement (tab);
-      gtk_alert_dialog_set_detail (GTK_ALERT_DIALOG (dialog), message_error);
-      gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), gtr_tab_get_window (tab));
+      adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+      adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
+      adw_dialog_present (dialog, GTK_WIDGET (tab));
       g_free (message_error);
     }
   else
@@ -539,17 +464,15 @@ gtr_tab_append_msgstr_page (const gchar * tab_label,
   label = gtk_label_new (tab_label);
 
   scroll = gtk_scrolled_window_new ();
-  gtk_widget_set_visible (scroll, TRUE);
+  gtk_widget_add_css_class (scroll, "card");
+  gtk_widget_set_margin_top (scroll, 6);
+  gtk_widget_set_size_request (scroll, -1, 75);
 
   view = gtr_view_new ();
-  gtk_widget_set_visible (view, TRUE);
+  gtk_widget_add_css_class (view, "inline");
 
-  //gtk_container_add (GTK_CONTAINER (scroll), view);
   gtk_scrolled_window_set_child (GTK_SCROLLED_WINDOW(scroll), view);
 
-  /*gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scroll),
-                                       GTK_SHADOW_IN);*/
-
   gtk_notebook_append_page (GTK_NOTEBOOK (box), scroll, label);
   gtr_view_set_lang (GTR_VIEW (view), lang_code);
 
@@ -784,10 +707,9 @@ gtr_tab_add_msgstr_tabs (GtrTab * tab)
 {
   GtrHeader *header;
   GtrTabPrivate *priv;
-  gchar *label;
   GtkTextBuffer *buf;
-  gint i = 0;
-  gchar *lang_code = NULL;
+  gint i;
+  g_autofree char *lang_code = NULL;
 
   priv = gtr_tab_get_instance_private (tab);
 
@@ -797,8 +719,10 @@ gtr_tab_add_msgstr_tabs (GtrTab * tab)
   header = gtr_po_get_header (priv->po);
   lang_code = gtr_header_get_language_code (header);
 
-  do
+  for (i = 0; i < gtr_header_get_nplurals (header); i++)
     {
+      g_autofree char *label = NULL;
+
       label = g_strdup_printf (_("Plural %d"), i);
       priv->trans_msgstr[i] = gtr_tab_append_msgstr_page (label,
                                                           priv->trans_notebook,
@@ -813,11 +737,7 @@ gtr_tab_add_msgstr_tabs (GtrTab * tab)
                               G_CALLBACK (emit_message_changed_signal), tab);
       g_signal_connect (buf, "notify::has-selection",
                         G_CALLBACK (emit_selection_changed), tab);
-      i++;
-      g_free (label);
     }
-  while (i < gtr_header_get_nplurals (header));
-  g_free (lang_code);
 }
 
 static void
@@ -836,34 +756,6 @@ on_state_notify (GtrPo      *po,
   g_object_notify (G_OBJECT (tab), "name");
 }
 
-static void
-sort_by_id_cb (GtkWidget *checkbutton, GtrTab* tab)
-{
-  if (gtk_check_button_get_active (GTK_CHECK_BUTTON (checkbutton)))
-    gtr_tab_sort_by (tab, GTR_MESSAGE_TABLE_SORT_ID);
-}
-
-static void
-sort_by_status_cb (GtkWidget *checkbutton, GtrTab* tab)
-{
-  if (gtk_check_button_get_active (GTK_CHECK_BUTTON (checkbutton)))
-    gtr_tab_sort_by (tab, GTR_MESSAGE_TABLE_SORT_STATUS);
-}
-
-static void
-sort_by_msgid_cb (GtkWidget *checkbutton, GtrTab* tab)
-{
-  if (gtk_check_button_get_active (GTK_CHECK_BUTTON (checkbutton)))
-    gtr_tab_sort_by (tab, GTR_MESSAGE_TABLE_SORT_MSGID);
-}
-
-static void
-sort_by_translated_cb (GtkWidget *checkbutton, GtrTab* tab)
-{
-  if (gtk_check_button_get_active (GTK_CHECK_BUTTON (checkbutton)))
-    gtr_tab_sort_by (tab, GTR_MESSAGE_TABLE_SORT_TRANSLATED);
-}
-
 static void
 gtr_tab_init (GtrTab * tab)
 {
@@ -878,10 +770,6 @@ gtr_tab_init (GtrTab * tab)
 
   g_signal_connect (tab, "message-changed", G_CALLBACK (update_status), NULL);
 
-  /*Load gsettings for flap */
-  priv->flap_state = g_settings_get_boolean (priv->state_settings,
-                                             GTR_SETTINGS_FLAP_STATE);
-
   /* Manage auto save data */
   priv->autosave = g_settings_get_boolean (priv->files_settings,
                                            GTR_SETTINGS_AUTO_SAVE);
@@ -906,17 +794,6 @@ gtr_tab_init (GtrTab * tab)
 
   g_signal_connect (priv->search_bar, "notify::search-mode-enabled",
                     G_CALLBACK (emit_searchbar_toggled), tab);
-
-  // TODO: related to header of gtr tab move to saperate header file
-  g_signal_connect (priv->sort_id, "toggled",
-                    G_CALLBACK(sort_by_id_cb), tab);
-  g_signal_connect (priv->sort_status, "toggled",
-                    G_CALLBACK(sort_by_status_cb), tab);
-  g_signal_connect (priv->sort_msgid, "toggled",
-                    G_CALLBACK(sort_by_msgid_cb), tab);
-  g_signal_connect (priv->sort_translated, "toggled",
-                    G_CALLBACK(sort_by_translated_cb), tab);
-  gtk_check_button_set_active (GTK_CHECK_BUTTON (priv->sort_id), TRUE);
 }
 
 static void
@@ -927,41 +804,21 @@ gtr_tab_finalize (GObject * object)
 
   priv = gtr_tab_get_instance_private (tab);
 
-  if (priv->timer != NULL)
-    g_timer_destroy (priv->timer);
-
   if (priv->autosave_timeout > 0)
     remove_autosave_timeout (tab);
 
   G_OBJECT_CLASS (gtr_tab_parent_class)->finalize (object);
 }
 
-static void
-save_pane_state(GtrTab *tab)
-{
-  GtrTabPrivate *priv;
-
-  priv = gtr_tab_get_instance_private (tab);
-
-  priv->flap_state = adw_flap_get_folded (priv->hbox);
-
-  g_settings_set_boolean (priv->state_settings, GTR_SETTINGS_FLAP_STATE,
-                          priv->flap_state);
-}
-
 static void
 gtr_tab_dispose (GObject * object)
 {
-  GtrTab *tab = GTR_TAB(object);
   GtrTabPrivate *priv;
 
   priv = gtr_tab_get_instance_private (GTR_TAB (object));
 
   if (!priv->dispose_has_run)
-    {
-      save_pane_state (tab);
-      priv->dispose_has_run = TRUE;
-    }
+    priv->dispose_has_run = TRUE;
 
   g_clear_object (&priv->po);
   g_clear_object (&priv->ui_settings);
@@ -1120,7 +977,7 @@ gtr_tab_class_init (GtrTabClass * klass)
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, msgstr_label);
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, trans_notebook);
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, context);
-  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, hbox);
+  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, overlay_split_view);
 
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, progress_box);
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, progress_revealer);
@@ -1131,16 +988,7 @@ gtr_tab_class_init (GtrTabClass * klass)
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, search_bar);
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, gtr_search_bar);
 
-  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, titlebar);
-  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, sort_id);
-  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, sort_status);
-  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, sort_msgid);
-  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, sort_translated);
-  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, order_menu_popover);
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, search_toggle);
-  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, undo);
-  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, redo);
-  gtk_widget_class_bind_template_child_private (widget_class, GtrTab, save);
   gtk_widget_class_bind_template_child_private (widget_class, GtrTab, upload);
 
   gtk_widget_class_bind_template_callback (widget_class, gtr_page_notify_child_revealed);
@@ -1154,15 +1002,6 @@ gtr_tab_class_init (GtrTabClass * klass)
 
 /***************************** Public funcs ***********************************/
 
-void
-gtr_tab_hide_sort_menu (GtrTab *tab)
-{
-  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
-
-  if (priv->sort_id)
-    gtk_popover_popdown (GTK_POPOVER (priv->order_menu_popover));
-}
-
 void
 gtr_tab_enable_find_button (GtrTab *tab,
                                  gboolean enable)
@@ -1173,34 +1012,6 @@ gtr_tab_enable_find_button (GtrTab *tab,
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (priv->search_toggle), enable);
 }
 
-void
-gtr_tab_enable_save (GtrTab *tab,
-                          gboolean enable)
-{
-  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
-  gtk_widget_set_sensitive (priv->save, enable);
-}
-
-void
-gtr_tab_update_undo_buttons (GtrTab *tab,
-                                  GtrView  *view)
-{
-  GtkSourceBuffer *active_document;
-  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
-  gboolean can_undo, can_redo;
-  g_return_if_fail (view);
-
-  active_document =
-    GTK_SOURCE_BUFFER (gtk_text_view_get_buffer (GTK_TEXT_VIEW (view)));
-  g_return_if_fail(active_document);
-
-  can_undo = gtk_text_buffer_get_can_undo (GTK_TEXT_BUFFER(active_document));
-  can_redo = gtk_text_buffer_get_can_redo (GTK_TEXT_BUFFER(active_document));
-
-  gtk_widget_set_sensitive (priv->undo, can_undo);
-  gtk_widget_set_sensitive (priv->redo, can_redo);
-}
-
 void
 gtr_tab_enable_upload (GtrTab *tab, gboolean enable)
 {
@@ -1208,13 +1019,6 @@ gtr_tab_enable_upload (GtrTab *tab, gboolean enable)
   gtk_widget_set_sensitive (priv->upload, enable);
 }
 
-GtkWidget *
-gtr_tab_get_header (GtrTab *tab)
-{
-  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
-  return priv->titlebar;
-}
-
 /**
  * gtr_tab_new:
  * @po: a #GtrPo
@@ -1230,12 +1034,9 @@ gtr_tab_new (GtrPo * po,
 {
   GtrTab *tab;
   GtrTabPrivate *priv;
-  GtrProfileManager *manager;
 
   g_return_val_if_fail (po != NULL, NULL);
 
-  manager = gtr_profile_manager_get_default();
-
   tab = g_object_new (GTR_TYPE_TAB, NULL);
 
   priv = gtr_tab_get_instance_private (tab);
@@ -1253,15 +1054,6 @@ gtr_tab_new (GtrPo * po,
   g_signal_connect (po, "notify::state",
                     G_CALLBACK (on_state_notify), tab);
 
-  g_signal_connect (po, "file-is-inconsistent-with-profile",
-                    G_CALLBACK (handle_file_is_inconsistent), tab);
-
-  g_signal_connect (manager, "active-profile-changed",
-                    G_CALLBACK (on_active_profile_changed), tab);
-
-    g_signal_connect (manager, "profile-modified",
-                    G_CALLBACK (on_profile_modified), tab);
-
   install_autosave_timeout_if_needed (tab);
 
   /* Now we have to initialize the number of msgstr tabs */
@@ -1270,11 +1062,6 @@ gtr_tab_new (GtrPo * po,
   gtr_message_table_populate (GTR_MESSAGE_TABLE (priv->message_table),
                               GTR_MESSAGE_CONTAINER (priv->po));
 
-  if (!gtr_po_consistent_with_profile (po))
-  {
-    gtr_po_emit_file_not_consistent (po);
-  }
-
   gtk_widget_set_visible (GTK_WIDGET (tab), TRUE);
   return tab;
 }
@@ -1748,6 +1535,36 @@ gtr_tab_copy_to_translation (GtrTab * tab)
   gtk_text_buffer_end_user_action (msgstr);
 }
 
+/**
+ * gtr_tab_copy_original:
+ * @tab: a #GtrTab
+ *
+ * Copies the text from the original text box to the clipboard.
+ */
+void
+gtr_tab_copy_original (GtrTab * tab)
+{
+  GtkTextBuffer *msgid;
+  GdkClipboard *clipboard;
+  g_autofree char *text = NULL;
+  GtkTextIter start, end;
+  GtrTabPrivate *priv;
+
+  g_return_if_fail (GTR_IS_TAB (tab));
+
+  priv = gtr_tab_get_instance_private (tab);
+
+  msgid = gtk_text_view_get_buffer (GTK_TEXT_VIEW (priv->text_msgid));
+
+  gtk_text_buffer_get_bounds (msgid, &start, &end);
+  text = gtk_text_buffer_get_text (msgid, &start, &end, FALSE);
+
+  clipboard = gtk_widget_get_clipboard (GTK_WIDGET (tab));
+  gdk_clipboard_set_text (clipboard, text);
+
+  gtr_window_add_toast_msg (GTR_WINDOW (priv->window), _("Copied to clipboard"));
+}
+
 /**
  * gtr_tab_block_movement:
  * @tab: a #GtrTab
@@ -2118,6 +1935,32 @@ gtr_tab_go_to_number (GtrTab * tab, gint number)
     }
 }
 
+/**
+ * gtr_tab_go_to_position:
+ * @tab: a #GtrTab
+ * @position: the position in the list to go
+ *
+ * Jumps to the message in the @position in the current message list order.
+ */
+void
+gtr_tab_go_to_position (GtrTab *tab, gint position)
+{
+  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
+  GtkSingleSelection *model = gtr_message_table_get_selection_model (
+      GTR_MESSAGE_TABLE (priv->message_table));
+  GtrMsg *msg = NULL;
+
+  gtk_single_selection_set_selected (model, position);
+  msg = GTR_MSG (gtk_single_selection_get_selected_item (model));
+
+  g_signal_emit (G_OBJECT (tab), signals[SHOWED_MESSAGE], 0, msg);
+
+  // Grabbing the focus in the GtrView to edit the message
+  // This is done in the idle add to avoid the focus grab from the
+  // message-table
+  g_idle_add ((GSourceFunc)msg_grab_focus, tab);
+}
+
 /**
  * gtr_tab_set_info:
  * @tab: a #GtrTab
@@ -2174,15 +2017,6 @@ gtr_tab_set_progress (GtrTab      *tab,
   g_free (untrans_text);
 }
 
-void
-gtr_tab_sort_by (GtrTab *tab,
-                 GtrMessageTableSortBy sort)
-{
-  GtrTabPrivate *priv;
-  priv = gtr_tab_get_instance_private (tab);
-  gtr_message_table_sort_by (GTR_MESSAGE_TABLE (priv->message_table), sort);
-}
-
 void
 gtr_tab_find_replace (GtrTab *tab,
                       gboolean set)
@@ -2207,3 +2041,10 @@ gtr_tab_get_selection_model (GtrTab *tab)
   GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
   return gtr_message_table_get_selection_model (GTR_MESSAGE_TABLE (priv->message_table));
 }
+
+GListStore *
+gtr_tab_get_model (GtrTab *tab)
+{
+  GtrTabPrivate *priv = gtr_tab_get_instance_private (tab);
+  return gtr_message_table_get_model (GTR_MESSAGE_TABLE (priv->message_table));
+}
