@@ -19,10 +19,9 @@
  *   Ignacio Casal Quinteiro <nacho.resa@gmail.com>
  *   Pablo Sanxiao <psanxiao@gmail.com>
  */
+#pragma once
 
-#ifndef __TAB_H__
-#define __TAB_H__
-
+#include <adwaita.h>
 #include <glib.h>
 #include <glib-object.h>
 #include <gtk/gtk.h>
@@ -35,34 +34,14 @@
 #include "gtr-search-bar.h"
 
 G_BEGIN_DECLS
-/*
- * Type checking and casting macros
- */
-#define GTR_TYPE_TAB		(gtr_tab_get_type ())
-#define GTR_TAB(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GTR_TYPE_TAB, GtrTab))
-#define GTR_TAB_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST((k), GTR_TYPE_TAB, GtrTabClass))
-#define GTR_IS_TAB(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), GTR_TYPE_TAB))
-#define GTR_IS_TAB_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), GTR_TYPE_TAB))
-#define GTR_TAB_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GTR_TYPE_TAB, GtrTabClass))
 
-/*
- * Main object structure
- */
-typedef struct _GtrTab GtrTab;
+#define GTR_TYPE_TAB (gtr_tab_get_type ())
 
-struct _GtrTab
-{
-  GtkBox parent_instance;
-};
-
-/*
- * Class definition
- */
-typedef struct _GtrTabClass GtrTabClass;
+G_DECLARE_DERIVABLE_TYPE (GtrTab, gtr_tab, GTR, TAB, AdwBin)
 
 struct _GtrTabClass
 {
-  GtkBoxClass parent_class;
+  AdwBinClass parent_class;
 
   void (*showed_message) (GtrTab * tab, GtrMsg * msg);
   void (*message_changed) (GtrTab * tab, GtrMsg * msg);
@@ -92,8 +71,6 @@ typedef enum
 /*
  * Public methods
  */
-GType gtr_tab_get_type (void) G_GNUC_CONST;
-
 GtrTab *gtr_tab_new (GtrPo * po, GtkWindow *window);
 
 GtrPo *gtr_tab_get_po (GtrTab * tab);
@@ -125,6 +102,8 @@ void gtr_tab_clear_msgstr_views (GtrTab * tab);
 
 void gtr_tab_copy_to_translation (GtrTab * tab);
 
+void gtr_tab_copy_original (GtrTab * tab);
+
 void gtr_tab_block_movement (GtrTab * tab);
 
 void gtr_tab_unblock_movement (GtrTab * tab);
@@ -150,6 +129,7 @@ gboolean gtr_tab_go_to_next_fuzzy_or_untrans (GtrTab * tab);
 gboolean gtr_tab_go_to_prev_fuzzy_or_untrans (GtrTab * tab);
 
 void gtr_tab_go_to_number (GtrTab * tab, gint number);
+void gtr_tab_go_to_position (GtrTab *tab, gint position);
 
 void gtr_tab_set_info_bar (GtrTab * tab, GtkWidget * infobar);
 
@@ -159,8 +139,6 @@ GtrMsg * gtr_tab_get_msg (GtrTab *tab);
 
 void gtr_tab_set_progress (GtrTab *tab, gint trans, gint untrans, gint fuzzy);
 
-void gtr_tab_sort_by (GtrTab *tab, GtrMessageTableSortBy sort);
-
 void gtr_tab_find_replace (GtrTab *tab, gboolean set);
 
 void gtr_tab_focus_search_bar (GtrTab *tab);
@@ -170,15 +148,11 @@ void gtr_tab_find_prev (GtrTab * tab);
 void gtr_tab_find_set_replace (GtrTab * tab, gboolean replace);
 
 GtkSingleSelection * gtr_tab_get_selection_model (GtrTab *tab);
+GListStore *gtr_tab_get_model (GtrTab *tab);
 
 /* notebook */
-void gtr_tab_enable_save (GtrTab *tab, gboolean enable);
 void gtr_tab_enable_upload (GtrTab *tab, gboolean enable);
-void gtr_tab_update_undo_buttons (GtrTab *tab, GtrView *view);
-GtkWidget *
-gtr_tab_get_header (GtrTab *tab);
 void gtr_tab_enable_find_button (GtrTab *tab, gboolean enable);
-void gtr_tab_hide_sort_menu (GtrTab *tab);
 
 GtkWindow *gtr_tab_get_window (GtrTab *tab);
 
@@ -191,5 +165,3 @@ gchar *_gtr_tab_get_tooltips (GtrTab *tab);
 gboolean _gtr_tab_can_close (GtrTab * tab);
 
 G_END_DECLS
-
-#endif /* __TAB_H__ */
