@@ -146,7 +146,8 @@ gtr_view_init (GtrView * view)
 
   gtk_text_view_set_extra_menu (GTK_TEXT_VIEW (view), extra_menu);
   gtk_widget_insert_action_group (GTK_WIDGET (view), "spelling", G_ACTION_GROUP (adapter));
-  spelling_text_buffer_adapter_set_enabled (adapter, TRUE);
+  g_settings_bind (priv->editor_settings, GTR_SETTINGS_SPELLCHECK, adapter,
+                   "enabled", G_SETTINGS_BIND_GET | G_SETTINGS_BIND_SET);
   gtr_view_set_lang (GTR_VIEW (view), "en_US");
 #endif
 }
@@ -169,12 +170,26 @@ gtr_view_dispose (GObject * object)
   G_OBJECT_CLASS (gtr_view_parent_class)->dispose (object);
 }
 
+static void
+gtr_view_finalize (GObject *object)
+{
+  GtrView *view = GTR_VIEW (object);
+  GtrViewPrivate *priv;
+
+  priv = gtr_view_get_instance_private (view);
+
+  g_clear_pointer (&priv->search_text, g_free);
+
+  G_OBJECT_CLASS (gtr_view_parent_class)->finalize (object);
+}
+
 static void
 gtr_view_class_init (GtrViewClass * klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
   object_class->dispose = gtr_view_dispose;
+  object_class->finalize = gtr_view_finalize;
 }
 
 /**
@@ -826,12 +841,7 @@ gtr_view_set_font (GtrView *view, char *font)
   str = pango_font_description_to_css (font_desc);
   css = g_strdup_printf ("textview  %s", str ?: "");
 
-/** Compatibility with Sdk//44 **/
-#if GTK_CHECK_VERSION (4, 11, 4)
   gtk_css_provider_load_from_string (priv->provider, css);
-#else
-  gtk_css_provider_load_from_data (priv->provider, css, -1);
-#endif
 }
 
 void
