@@ -66,21 +66,18 @@
 typedef struct
 {
   GSettings *state_settings;
+  GSettings *ui_settings;
   GSettings *tm_settings;
   GtrTranslationMemory *translation_memory;
 
   GtrCodeView *codeview;
 
-  GtkWidget *header_bar;
-  GtkWidget *main_box;
-
-  GtkWidget *header_stack;
-  GtkWidget *stack;
-
   GtkWidget *projects;
   GtkWidget *dlteams;
   GtkWidget *greeter;
 
+  AdwNavigationView *navigation_view;
+
   GtkWidget *toast_overlay;
 
   GtrTab *active_tab;
@@ -103,11 +100,6 @@ struct _GtrWindow
 
 G_DEFINE_FINAL_TYPE_WITH_PRIVATE (GtrWindow, gtr_window, ADW_TYPE_APPLICATION_WINDOW)
 
-enum
-{
-  TARGET_URI_LIST = 100
-};
-
 static void update_saved_state (GtrPo *po, GParamSpec *param, gpointer window);
 
 static void
@@ -119,15 +111,6 @@ free_match (gpointer data)
   g_slice_free (GtrTranslationMemoryMatch, match);
 }
 
-static void
-update_undo_state (GtrTab     *tab,
-                   GtrMsg     *msg,
-                   GtrWindow  *window)
-{
-  GtrView *active_view = gtr_window_get_active_view (window);
-  gtr_tab_update_undo_buttons (GTR_TAB (tab), active_view);
-}
-
 /*
  * gtr_window_update_statusbar_message_count:
  * 
@@ -163,7 +146,7 @@ drag_data_received_cb (GtkDropTarget * drop_target,
                        gpointer data)
 {
   GtrWindow * window = GTR_WINDOW (data);
-  GError * error = NULL;
+  g_autoptr (GError) error = NULL;
 
   if (!G_VALUE_HOLDS (value, G_TYPE_FILE))
     return FALSE;
@@ -172,9 +155,10 @@ drag_data_received_cb (GtkDropTarget * drop_target,
   gtr_open (g_value_get_object (value), window, &error);
   if (error != NULL)
     {
-      GtkAlertDialog *dialog = gtk_alert_dialog_new ("%s", error->message);
-      gtk_alert_dialog_show (GTK_ALERT_DIALOG (dialog), GTK_WINDOW (window));
-      g_error_free (error);
+      AdwDialog *dialog = adw_alert_dialog_new (NULL, error->message);
+      adw_alert_dialog_add_response (ADW_ALERT_DIALOG (dialog), "ok", _("OK"));
+      adw_alert_dialog_set_default_response (ADW_ALERT_DIALOG (dialog), "ok");
+      adw_dialog_present (ADW_DIALOG (dialog), GTK_WIDGET (window));
     }
   return TRUE;
 }
@@ -187,8 +171,6 @@ set_window_title (GtrWindow * window, gboolean with_path)
   GtrTab *active_tab;
   GFile *file;
   g_autofree gchar *title;
-  GtrWindowPrivate *priv = gtr_window_get_instance_private(window);
-  GtkHeaderBar *header;
 
   if (with_path)
     {
@@ -204,13 +186,15 @@ set_window_title (GtrWindow * window, gboolean with_path)
         {
           /* Translators: this is the title of the window with a modified document */
           title = g_strdup_printf (_("*%s — Translation Editor"), basename);
-          gtr_tab_enable_save (GTR_TAB (priv->active_tab), TRUE);
+          gtk_widget_action_set_enabled (GTK_WIDGET (window), "win.save",
+                                         TRUE);
         }
       else
         {
           /* Translators: this is the title of the window with a document opened */
           title = g_strdup_printf (_("%s — Translation Editor"), basename);
-          gtr_tab_enable_save (GTR_TAB (priv->active_tab), FALSE);
+          gtk_widget_action_set_enabled (GTK_WIDGET (window), "win.save",
+                                         FALSE);
         }
 
       g_free (basename);
@@ -222,10 +206,6 @@ set_window_title (GtrWindow * window, gboolean with_path)
     }
 
   gtk_window_set_title (GTK_WINDOW (window), title);
-
-  // notebook headerbar
-  header = GTK_HEADER_BAR (gtr_tab_get_header (GTR_TAB (priv->active_tab)));
-  gtk_widget_set_visible (GTK_WIDGET (header), TRUE);
 }
 
 static void
@@ -243,9 +223,11 @@ gtr_window_init (GtrWindow *window)
 {
   //GtkTargetList *tl;
   GtrWindowPrivate *priv = gtr_window_get_instance_private(window);
+  GAction *sort_action;
 
   priv->search_bar_shown = FALSE;
   priv->state_settings = g_settings_new ("org.gnome.gtranslator.state.window");
+  priv->ui_settings = g_settings_new ("org.gnome.gtranslator.preferences.ui");
   priv->active_tab = NULL;
 
   /* loading custom styles */
@@ -264,26 +246,12 @@ gtr_window_init (GtrWindow *window)
 
   // project selection
   priv->projects = GTK_WIDGET (gtr_projects_new (window));
-  gtk_stack_add_named (GTK_STACK (priv->stack), priv->projects, "projects");
-  gtk_stack_add_named (GTK_STACK (priv->header_stack),
-                       gtr_projects_get_header (GTR_PROJECTS (priv->projects)),
-                       "projects");
 
   // DL team selection
   priv->dlteams = GTK_WIDGET (gtr_dl_teams_new (window));
-  gtk_stack_add_named (GTK_STACK (priv->stack), priv->dlteams, "dlteams");
-  gtk_stack_add_named (GTK_STACK (priv->header_stack),
-                       gtr_dl_teams_get_header (GTR_DL_TEAMS (priv->dlteams)),
-                       "dlteams");
 
   // Greeter, First launch view
   priv->greeter = GTK_WIDGET (gtr_greeter_new (window));
-  gtk_stack_add_named (GTK_STACK (priv->stack), priv->greeter, "greeter");
-  gtk_stack_add_named (GTK_STACK (priv->header_stack),
-                       gtr_greeter_get_header (GTR_GREETER (priv->greeter)),
-                       "greeter");
-
-  gtk_widget_set_visible (priv->stack, TRUE);
 
   // translation memory
   priv->translation_memory = GTR_TRANSLATION_MEMORY (gtr_gda_new());
@@ -296,7 +264,9 @@ gtr_window_init (GtrWindow *window)
                                                             "max-length-diff"));
   gtr_translation_memory_set_max_items (priv->translation_memory, 10);
 
-  gtr_window_show_projects (window);
+  sort_action
+    = g_settings_create_action (priv->ui_settings, GTR_SETTINGS_SORT_ORDER);
+  g_action_map_add_action (G_ACTION_MAP (window), sort_action);
 }
 
 static void
@@ -326,6 +296,7 @@ gtr_window_dispose (GObject * object)
     }
 
   g_clear_object (&priv->state_settings);
+  g_clear_object (&priv->ui_settings);
   g_clear_object (&priv->prof_manager);
   g_clear_object (&priv->translation_memory);
   g_clear_object (&priv->tm_settings);
@@ -340,6 +311,46 @@ gtr_window_finalize (GObject * object)
   G_OBJECT_CLASS (gtr_window_parent_class)->finalize (object);
 }
 
+void
+gtr_window_save_current_tab (GtrWindow *self)
+{
+  g_autoptr (GError) error = NULL;
+  GtrTab *current;
+  GtrPo *po;
+
+  current = gtr_window_get_active_tab (self);
+  po = gtr_tab_get_po (current);
+
+  gtr_po_save_file (po, &error);
+
+  if (error)
+    {
+      AdwAlertDialog *dialog;
+      dialog = ADW_ALERT_DIALOG (adw_alert_dialog_new (
+          _("Could not Save"), error->message));
+      adw_alert_dialog_add_response (dialog, "ok", _("OK"));
+      adw_alert_dialog_set_default_response (dialog, "ok");
+      adw_alert_dialog_set_close_response (dialog, "ok");
+      adw_alert_dialog_choose (
+          dialog, GTK_WIDGET (self), NULL,
+          (GAsyncReadyCallback)adw_alert_dialog_choose_finish, NULL);
+      return;
+    }
+
+  /* We have to change the state of the tab */
+  gtr_po_set_state (po, GTR_PO_STATE_SAVED);
+  gtr_window_add_toast_msg (self, _("File saved"));
+}
+
+static void
+on_save_action (GtkWidget *widget, const char *action_name,
+                GVariant *parameter)
+{
+  GtrWindow *self = GTR_WINDOW (widget);
+
+  gtr_window_save_current_tab (self);
+}
+
 static void
 gtr_window_class_init (GtrWindowClass *klass)
 {
@@ -352,11 +363,12 @@ gtr_window_class_init (GtrWindowClass *klass)
                                                "/org/gnome/translator/gtr-window.ui");
 
   /* Main layout widgets */
-  gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), GtrWindow, header_bar);
-  gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), GtrWindow, main_box);
-  gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), GtrWindow, stack);
-  gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), GtrWindow, header_stack);
   gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass), GtrWindow, toast_overlay);
+  gtk_widget_class_bind_template_child_private (GTK_WIDGET_CLASS (klass),
+                                                GtrWindow, navigation_view);
+
+  gtk_widget_class_install_action (GTK_WIDGET_CLASS (klass), "win.save", NULL,
+                                   on_save_action);
 }
 
 static void
@@ -374,8 +386,10 @@ gtr_window_remove_tab (GtrWindow * window)
   GtrWindowPrivate *priv = gtr_window_get_instance_private (window);
   if (priv->active_tab != NULL)
   {
-    if (gtk_stack_get_child_by_name (GTK_STACK (priv->stack), "poeditor"))
-      gtk_stack_remove (GTK_STACK (priv->stack), GTK_WIDGET (priv->active_tab));
+    AdwNavigationPage *page;
+    page = adw_navigation_view_find_page (priv->navigation_view, "poeditor");
+    if (page)
+      adw_navigation_view_remove (priv->navigation_view, page);
 
     priv->active_tab = NULL;
   }
@@ -396,39 +410,32 @@ gtr_window_create_tab (GtrWindow * window, GtrPo * po)
 {
   GtrWindowPrivate *priv = gtr_window_get_instance_private (window);
   GtrTab *tab;
+  AdwNavigationPage *page;
 
   tab = gtr_tab_new (po, GTK_WINDOW (window));
   priv->active_tab = tab;
 
   g_signal_connect_after (tab,
-                          "message_changed",
+                          "message-changed",
                           G_CALLBACK
                           (gtr_window_update_statusbar_message_count),
                           window);
 
-  g_signal_connect_after (tab,
-                          "message_changed",
-                          G_CALLBACK (update_undo_state),
-                          window);
-  g_signal_connect_after (tab,
-                          "showed-message",
-                          G_CALLBACK (update_undo_state),
-                          window);
-
-  gtk_widget_set_visible (GTK_WIDGET (tab), TRUE);
   gtr_window_update_statusbar_message_count(priv->active_tab,NULL, window);
 
-  update_undo_state (tab, NULL, window);
-
-  if (gtk_stack_get_child_by_name (GTK_STACK (priv->stack), "poeditor") == NULL) {
-    gtk_stack_add_named (GTK_STACK (priv->stack), GTK_WIDGET(priv->active_tab), "poeditor");
-  }
-
-  if (gtk_stack_get_child_by_name (GTK_STACK (priv->header_stack), "poeditor") == NULL) {
-    gtk_stack_add_named (GTK_STACK (priv->header_stack),
-                         gtr_tab_get_header (GTR_TAB (priv->active_tab)),
-                         "poeditor");
-  }
+  page = adw_navigation_view_find_page (priv->navigation_view, "poeditor");
+  if (!page)
+    {
+      page = adw_navigation_page_new (GTK_WIDGET (tab), _("Translation Editor"));
+      adw_navigation_page_set_can_pop (page, FALSE);
+      adw_navigation_page_set_tag (page, "poeditor");
+      adw_navigation_view_add (priv->navigation_view, page);
+    }
+  else
+    {
+      adw_navigation_page_set_child (page, GTK_WIDGET (tab));
+      adw_navigation_view_pop_to_tag (priv->navigation_view, "poeditor");
+    }
 
   // code view
   priv->codeview = gtr_code_view_new (window);
@@ -603,18 +610,19 @@ gtr_window_show_projects (GtrWindow *window)
 {
   GtrWindowPrivate *priv = gtr_window_get_instance_private(window);
 
-  gtk_stack_set_visible_child_name (GTK_STACK (priv->header_stack), "projects");
-  gtk_stack_set_visible_child_name (GTK_STACK (priv->stack), "projects");
-  gtk_window_set_title (GTK_WINDOW (window), _("Select a Po file"));
+  adw_navigation_view_push (priv->navigation_view,
+                            ADW_NAVIGATION_PAGE (priv->projects));
 }
 
 void
 gtr_window_show_poeditor (GtrWindow *window)
 {
   GtrWindowPrivate *priv = gtr_window_get_instance_private(window);
+  AdwNavigationPage *page;
 
-  gtk_stack_set_visible_child_name (GTK_STACK (priv->header_stack), "poeditor");
-  gtk_stack_set_visible_child_name (GTK_STACK (priv->stack), "poeditor");
+  page = adw_navigation_view_get_visible_page (priv->navigation_view);
+  if (g_strcmp0 ("poeditor", adw_navigation_page_get_tag (page)) != 0)
+    adw_navigation_view_push_by_tag (priv->navigation_view, "poeditor");
 }
 
 void
@@ -622,12 +630,17 @@ gtr_window_show_dlteams (GtrWindow *window)
 {
   GtrWindowPrivate *priv = gtr_window_get_instance_private(window);
 
-  gtk_stack_set_visible_child_name (GTK_STACK (priv->header_stack), "dlteams");
-  gtk_stack_set_visible_child_name (GTK_STACK (priv->stack), "dlteams");
-  gtk_window_set_title (GTK_WINDOW (window), _("Load from Damned Lies"));
+  if (!adw_navigation_view_find_page (priv->navigation_view, "dlteams"))
+    {
+      adw_navigation_view_add (priv->navigation_view,
+                               ADW_NAVIGATION_PAGE (priv->dlteams));
 
-  /* Load teams and modules automatically */
-  gtr_dl_teams_load_json (GTR_DL_TEAMS (priv->dlteams));
+      /* Load teams and modules automatically */
+      gtr_dl_teams_load_json (GTR_DL_TEAMS (priv->dlteams));
+    }
+
+  adw_navigation_view_push (priv->navigation_view,
+                            ADW_NAVIGATION_PAGE (priv->dlteams));
 }
 
 void
@@ -635,9 +648,8 @@ gtr_window_show_greeter (GtrWindow *window)
 {
   GtrWindowPrivate *priv = gtr_window_get_instance_private (window);
 
-  gtk_stack_set_visible_child_name (GTK_STACK (priv->header_stack), "greeter");
-  gtk_stack_set_visible_child_name (GTK_STACK (priv->stack), "greeter");
-  gtk_window_set_title (GTK_WINDOW (window), _("Welcome to Translation Editor"));
+  adw_navigation_view_push (priv->navigation_view,
+                            ADW_NAVIGATION_PAGE (priv->greeter));
 }
 
 void
@@ -646,10 +658,9 @@ gtr_window_show_tm_dialog (GtrWindow *window)
   GtrWindowPrivate *priv = gtr_window_get_instance_private(window);
   GtkWidget *dlg;
 
-  dlg = gtr_translation_memory_dialog_new (GTK_WINDOW (window),
-                                           priv->translation_memory);
+  dlg = gtr_translation_memory_dialog_new (priv->translation_memory);
 
-  gtk_window_present (GTK_WINDOW (dlg));
+  adw_dialog_present (ADW_DIALOG (dlg), GTK_WIDGET (window));
 }
 
 GtrTranslationMemory *
@@ -720,14 +731,6 @@ gtr_window_tm_keybind (GtrWindow *window,
   g_list_free_full (tm_list, free_match);
 }
 
-void
-gtr_window_hide_sort_menu (GtrWindow *window)
-{
-  GtrWindowPrivate *priv = gtr_window_get_instance_private (window);
-
-  gtr_tab_hide_sort_menu (GTR_TAB (priv->active_tab));
-}
-
 void
 gtr_window_show_search_bar (GtrWindow *window,
                             gboolean show)
