@@ -41,10 +41,11 @@ typedef struct
 
 struct _GtrTranslationMemoryDialog
 {
-  GtkWindow parent;
+  AdwDialog parent;
 };
 
-G_DEFINE_TYPE_WITH_PRIVATE (GtrTranslationMemoryDialog, gtr_translation_memory_dialog, GTK_TYPE_WINDOW)
+G_DEFINE_TYPE_WITH_PRIVATE (GtrTranslationMemoryDialog,
+                            gtr_translation_memory_dialog, ADW_TYPE_DIALOG)
 
 static void
 select_folder_cb (GtkFileDialog *dialog, GAsyncResult *res, gpointer user_data)
@@ -78,7 +79,7 @@ select_directory_activated_cb (GtrTranslationMemoryDialog *dlg)
 
   gtk_file_dialog_select_folder (
     dialog,
-    GTK_WINDOW (dlg),
+    GTK_WINDOW (gtk_widget_get_root (GTK_WIDGET (dlg))),
     NULL,
     (GAsyncReadyCallback) (select_folder_cb),
     dlg
@@ -244,13 +245,9 @@ launch_gtr_scan_dir_task (GtrTranslationMemoryDialog *dlg,
                           ScanDirTaskData            *data)
 {
   GTask *task;
-  GCancellable *cancellable;
   IdleData *idata;
   GtrTranslationMemoryDialogPrivate *priv = gtr_translation_memory_dialog_get_instance_private (dlg);
 
-  cancellable = g_cancellable_new ();
-  // TODO: connect cancellable cancel signal
-
   idata = g_new0 (IdleData, 1);
   idata->list = NULL;
   idata->tm = priv->translation_memory;
@@ -262,9 +259,7 @@ launch_gtr_scan_dir_task (GtrTranslationMemoryDialog *dlg,
 
   gtk_widget_set_sensitive (priv->add_database_button, FALSE);
 
-  task = g_task_new (dlg,
-                     cancellable,
-                     (GAsyncReadyCallback)scan_dir_task_ready_cb,
+  task = g_task_new (dlg, NULL, (GAsyncReadyCallback)scan_dir_task_ready_cb,
                      idata);
 
   g_task_set_task_data (task, data, (GDestroyNotify)task_data_destroy);
@@ -358,8 +353,7 @@ gtr_translation_memory_dialog_init (GtrTranslationMemoryDialog *dlg)
 }
 
 GtkWidget *
-gtr_translation_memory_dialog_new (GtkWindow *window,
-                                   GtrTranslationMemory *translation_memory)
+gtr_translation_memory_dialog_new (GtrTranslationMemory *translation_memory)
 {
   GtrTranslationMemoryDialog *dlg;
   GtrTranslationMemoryDialogPrivate *priv;
@@ -370,10 +364,5 @@ gtr_translation_memory_dialog_new (GtkWindow *window,
   /* FIXME: use a property */
   priv->translation_memory = translation_memory;
 
-  if (window != gtk_window_get_transient_for (GTK_WINDOW (dlg)))
-    {
-      gtk_window_set_transient_for (GTK_WINDOW (dlg), window);
-    }
-
   return GTK_WIDGET (dlg);
 }
